## **Sports Biomechanics**

**[ISSN: (Print) (Online) Journal homepage: https://www.tandfonline.com/loi/rspb20](https://www.tandfonline.com/loi/rspb20)**

# **The biomechanics of running and running styles: a** **synthesis**

**Ben T. van Oeveren, Cornelis J. de Ruiter, Peter J. Beek & Jaap H. van Dieën**

**To cite this article:** Ben T. van Oeveren, Cornelis J. de Ruiter, Peter J. Beek & Jaap H. van Dieën
(2021): The biomechanics of running and running styles: a synthesis, Sports Biomechanics, DOI:
[10.1080/14763141.2021.1873411](https://www.tandfonline.com/action/showCitFormats?doi=10.1080/14763141.2021.1873411)

**To link to this article:** [https://doi.org/10.1080/14763141.2021.1873411](https://doi.org/10.1080/14763141.2021.1873411)

© 2021 The Author(s). Published by Informa
UK Limited, trading as Taylor & Francis
Group.

Published online: 04 Mar 2021.

[Submit your article to this journal](https://www.tandfonline.com/action/authorSubmission?journalCode=rspb20&show=instructions)

Article views: 5257

[View related articles](https://www.tandfonline.com/doi/mlt/10.1080/14763141.2021.1873411)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/14763141.2021.1873411&domain=pdf&date_stamp=2021-03-04)

Full Terms & Conditions of access and use can be found at
[https://www.tandfonline.com/action/journalInformation?journalCode=rspb20](https://www.tandfonline.com/action/journalInformation?journalCode=rspb20)

SPORTS BIOMECHANICS

<https://doi.org/10.1080/14763141.2021.1873411>

### **The biomechanics of running and running styles: a synthesis**

Ben T. van Oeveren, Cornelis J. de Ruiter, Peter J. Beek
and Jaap H. van Dieën

Department of Human Movement Sciences, Faculty of Behavioural and Movement Sciences, Vrije
Universiteit Amsterdam, Amsterdam Movement Sciences, Amsterdam, The Netherlands

**ABSTRACT**
Running movements are parametrised using a wide variety of
devices. Misleading interpretations can be avoided if the interde­
pendencies and redundancies between biomechanical parameters
are taken into account. In this synthetic review, commonly mea­
sured running parameters are discussed in relation to each other,
culminating in a concise, yet comprehensive description of the full
spectrum of running styles. Since the goal of running movements is
to transport the body centre of mass (BCoM), and the BCoM trajec­
tory can be derived from spatiotemporal parameters, we anticipate
that different running styles are reflected in those spatiotemporal
parameters. To this end, this review focuses on spatiotemporal
parameters and their relationships with speed, ground reaction
force and whole-body kinematics. Based on this evaluation, we
submit that the full spectrum of running styles can be described
by only two parameters, namely the step frequency and the duty
factor (the ratio of stance time and stride time) as assessed at a
given speed. These key parameters led to the conceptualisation of a
so-called Dual-axis framework. This framework allows categorisa­
tion of distinctive running styles (coined ‘Stick’, ‘Bounce’, ‘Push’,
‘Hop’, and ‘Sit’) and provides a practical overview to guide future
measurement and interpretation of running biomechanics.

**Introduction**

**ARTICLE HISTORY**
Received 6 July 2020
Accepted 5 January 2021

**KEYWORDS**
Biomechanics; kinematics;
running; wearable
technology; qualitative
analysis

Runners, coaches, clinicians, and scientists use wearable technology, optical systems and
force transducers to quantify running. Typically, measurements are performed to either
optimise running economy (Kyrolainen et al., 2001; Moore, 2016; Tawa & Louw, 2018;
Van Hooren et al., 2019) or reduce injury risk (Brindle et al., 2019; Ceyssens et al., 2019;
Goss & Gross, 2012). However, without considering the interdependencies and redun­
dancies between parameters, false claims and misleading interpretations are readily
made. The analysis of isolated parameters may explain in part why the conclusions
regarding different kinematic and kinetic parameters and running economy are often
contradictory (Van Hooren et al., 2020), and why the literature on the relationship
between running technique and injury risk suffers from considerable inconsistencies
(Brindle et al., 2019; Ceyssens et al., 2019; Mousavi et al., 2019). Furthermore, feedback
from commercial applications is predominately based on isolated parameters.

**CONTACT** Cornelis J. de Ruiter <c.j.de.ruiter@vu.nl>

© 2021 The Author(s). Published by Informa UK Limited, trading as Taylor & Francis Group.
This is an Open Access article distributed under the terms of the Creative Commons Attribution-NonCommercial-NoDerivatives License
(<http://creativecommons.org/licenses/by-nc-nd/4.0/>), which permits non-commercial re-use, distribution, and reproduction in any med­
ium, provided the original work is properly cited, and is not altered, transformed, or built upon in any way.

2 B. T. VAN OEVEREN ET AL.

Unfortunately, the analysis, presentation and interpretation of isolated biomechanical
parameters are also common in science, in spite of the recognition of several researchers
that running styles cannot be described based on a single parameter (Black et al., 2018;
Folland et al., 2017; Williams & Cavanagh, 1985). The effectiveness of feedback or studies
based on isolated parameters should therefore be reconsidered.

In this review, we define a running style as a visually distinguishable movement
pattern of a runner. It is likely that such a running style can be characterised by a set
of parameters. Yet, the key parameters required to characterise the full spectrum of
running styles remain to be determined. Identification of the minimal set of parameters
and reaching consensus on their interpretation would help to clarify the existing litera­
ture on running biomechanics and facilitate future studies and feedback applications to
design targeted interventions to improve running performance or reduce injury risk.

Therefore, this synthetic review aims to identify the (minimal) set of parameters that
lead to a concise, yet, comprehensive description of the full spectrum of running styles. To
this end, the interdependency between the parameters and their relationship with speed will
be studied. Since the goal of locomotion is to transport the BCoM, we expect that
fundamental differences between running styles will be apparent in the BCoM trajectory.
In running, most of the body’s movements occur in the sagittal plane. This is reflected by
the relatively high force amplitudes in the vertical and the horizontal direction compared to
the medio-lateral direction (Hamner & Delp, 2013; Nordin et al., 2017). Likewise, energy
expenditure in running is predominately determined by movements in the sagittal plane.
Arellano and Kram (2014) have estimated that runners use 80% of the net metabolic cost
for bodyweight support and forward propulsion, 7% for leg swing, and only 2% for
sideward balance control, leaving 11% of the variance unexplained. Therefore, we believe
it is safe to assume that differences in running styles will be apparent in the sagittal plane
trajectory of the BCoM. Reasonably accurate predictions of the BCoM trajectory in walk­
ing, hopping and running have been made using the spring-mass model (Blickhan, 1989;
Coleman et al., 2012; Farley & Gonzalez, 1996). According to this model, which is in
essence a mass on a weightless pogo Stick (the spring leg), the runner’s mass, leg length and
velocity determine the bouncing trajectory of the BCoM (Arampatzis et al., 1999; Blickhan,
1989; Brughelli & Cronin, 2008a). The spring-mass model and its assumptions are therefore
discussed in detail later in this review to explain biomechanical interdependencies as well as
the relevance of specific spatiotemporal parameters.

The approximately sinusoidal BCoM trajectory in the sagittal plane is characterised by
the frequency of movement, vertical displacement during the stance and flight phase, and
the landing/take-off asymmetry (Figure 1). These characteristics can be predicted from
commonly used spatiotemporal parameters, including step frequency (SF), step length
(SL), stance time (tstance), flight time (tstance), and vertical displacement (VDstep). The
characteristics of the BCoM and the associated spatiotemporal parameters will be
discussed systematically in this review to identify the key parameters to describe a
running style. The BCoM movements result from forces exerted on the ground, which
in turn result from joint moments in limbs and trunk (Figure 2). Consequently, spatio­
temporal parameters, limb and trunk kinetics and ground reaction forces are interrelated
mechanically. To provide a full overview, we subsequently discuss the relationship
between limb and trunk kinematics and the spatiotemporal parameters. Ultimately,

SPORTS BIOMECHANICS 3

these discussions will culminate in a Dual-axis framework, which characterises different
running styles based on the identified key parameters.

**Figure 1.** A) Hierarchical breakdown of the three levels and their subphases in relation to running
speed. In panel b), a visualisation of each level. On the first level, the balance between step frequency
and step length to determine movement speed. On the second level, the subdivision of a step into
stance and flight phase, which further specifies the timing, horizontal distance and vertical displace­
ment per phase. On the third level, the ratio between braking and propulsion phase. The ratios
between the subphases at each level, together characterise the sinusoidal body centre of mass
trajectory (BCoM). This review is structured accordingly.

**Step frequency and step length**

Between running styles, SF varies. SF can be readily observed and measured, and research
has shown that runners can voluntarily modify SF at a given speed (Moore, 2016). SF
modification relates to the kinematics and kinetics of the runner. Therefore, many
scientists and practitioners measure SF to assess running style. Running speed is the
product of SF and SL, implying that if running speed is held constant, SL and SF are
inversely related (Figure 3, Appendix Equation 1). To undercut suggestions that either SF
or SL can be changed independently at a given speed, it might be clearer to consider the
relation between SF and SL as a ratio (SL/SF) that varies with speed. SF is simply a
conversion of step time and can be calculated with SF = 60/(tstance + tflight) (Appendix,
Equation 2, 3). In words, SF is affected directly by changes in tstance and tflight. Since any
change in GRF orientation or amplitude is likely to affect tstance or tflight, it can be
expected that most, if not all, parameters directly or indirectly affect the SL/SF ratio.

Runners are commonly advised to run at 180 steps per minute (e.g., Daniels, 2013).
This advice supposes that SF should be consistent across running speeds and individuals.
Other common assumptions are that better runners run with higher SF’s and that
running with higher SF’s reduces injury risk (Daniels, 2013; Lieberman et al., 2015).
However, evidence to support these assumptions is equivocal. The assumption that SF is
constant across running speeds seems to be invalid given that numerous studies have
shown that both SL and SF have a positive curvilinear relationship with speed (Bailey et
al., 2017; Mercer & Dolgan, 2008; Le Meur et al., 2013; Nummela et al., 2007; OguetaAlday et al., 2014; Padulo et al., 2012; Sinning & Forsyth, 1970; Van Oeveren et al., 2019;

4 B. T. VAN OEVEREN ET AL.

**Figure 2.** Overview of the parameters discussed in this review. The BCoM trajectory in place (panel a)
or time (panel b) results from the ground reaction force (GRF, panel c) following from joint moments in
limbs and trunk (panel d). Consequently, the spatiotemporal parameters, limb and trunk kinetics and
ground reaction forces are interrelated mechanically. The landing/take-off asymmetry can be assessed
by dividing the stance phase in a braking phase and a propulsion phase using the sign change of the
horizontal GRF (GRFx). Typically, for speeds below 20 km/h, tbrake<tprop and take-off height>touchdown height as depicted with -y and +y. Based the vertical GRF (GRFy) the effective stance time can be
determined. As visualised in panel c, the effective stance time is defined by the time where the GRFy
exceeds the GRFy required to support the body weight (Fy,BW).

Weyand et al., 2000). SL increases more rapidly at speeds below ~20 km/h and SF
increases more rapidly at speeds above ~20 km/h (Figure 3.a). The flattening of the SL
curve at a certain speed may suggest that SL limits a further increase in speed. For speeds
up to 25 km/h, the ankle plantar flexors, soleus and gastrocnemius contribute greatly to
vertical forces and thus the increase in SL (Dorn et al., 2012). At speeds above 25 km/h,
the strategy shifts to bringing the swing leg quickly forward using the hip musculature,
iliopsoas, gluteus maximus and hamstrings to increase SF further (Dorn et al., 2012). An
early shift towards high SF at relatively low speeds may indicate an inability of the runner

SPORTS BIOMECHANICS 5

**Figure 3.** Parameter changes across running speeds. Panel a): step length (–, SL, in metres) and step
frequency (:, SF, in steps per minute). Panel b): Duty Factor (—, DF), stance time (–, tstance), flight time
(tflight) in seconds. Panel c): Measured vertical displacement (—, VDstep) divided in calculated vertical
displacement during stance phase (–, VDstance) in cm (see Appendix, Equation 19) resulting in vertical
displacement during flight phase (:, VDflight = VDstep—VDstance). The relations presented are based on
data (captured with a Garmin Forerunner 620) derived from 470 training sessions of an experienced
endurance runner (5 km in 16:20) (Van Oeveren et al., 2019).

to generate power with (or via) the calf muscles and the runner would then be more
reliant on hip musculature. Hence, the shift in SL/SF ratio across running speeds may
reveal individual limitations and strengths. Note that such differences may only be
revealed when the individuals in question are challenged to run at high speeds.

Once corrected for speed, individual differences in the SL/SF ratio still exist.
Individual characteristics such as leg length, body mass and age have been shown to
partly explain individual differences in SF’s (Van Oeveren et al., 2019). Evidence for SF
differences related to performance levels is mixed. Remarkably high SF’s have been
found in highly trained runners (193 spm, 17.5 km/h) compared to well trained (181
spm, 17.9 km/h) and untrained runners (178 spm, 16.7 km/h) (Slawinski & Billat,
2004). However, Preece et al. (2019) did not find significant differences in SF’s between
high performance and recreational runners after having corrected SF for leg length
(11.9–20.2 km/h). Also, in training data of 256 runners, performance and years of
experience did not contribute significantly to the prediction of SF, in contrast to
(estimated) leg length, body mass and age (Van Oeveren et al., 2019). Several studies
reported even lower SF’s in faster runners (8–20 km/h) (Da Rosa et al., 2019) and lower
SF’s in elite marathon runners (161–165 spm, 14–18 km/h) compared to amateur
runners (170–177 spm) (Padulo et al., 2012). Together these results suggest that
more experienced and faster runners are just as likely, if not more so, to run with
lower SF’s instead of higher SF’s.

6 B. T. VAN OEVEREN ET AL.

The relationship between SF and injury incidence is indirect. Several authors have
found an association between SF and potential injury-related kinetic variables such as
impact forces, high tibial accelerations or high joint forces (e.g., Heiderscheit et al., 2011;
Hobara et al., 2012; Lenhart et al., 2014; Lieberman et al., 2015; Willson et al., 2015).
However, only one study found a direct relationship between SF and injury risk
(Luedke et al., 2016). While in a recent large-scale study, injury history, experience and
performance were not associated with SF at given speeds (Van Oeveren et al., 2019).

Several studies have shown that both high and low imposed SF’s increase the (aerobic)
energy cost estimated with gas exchange equipment and heart rate monitors (Cavanagh &
Williams, 1982; Farley & Gonzalez, 1996; I. Hunter et al., 2017; I. Hunter & Smith, 2007;
Mercer & Dolgan, 2008; De Ruiter et al., 2019, 2013; Snyder & Farley, 2011; Van
Oeveren et al., 2017). Most runners seem to self-optimise the SL/SF ratio (I. Hunter
et al., 2017), except for novice runners (De Ruiter et al., 2013; Van Oeveren et al., 2017)
and some experienced runners (De Ruiter et al., 2020). Based on the current literature,
it is safe to assume that runners with sufficient running experience mostly have adopted
a running style with low energy consumption through a process of self-optimisation
(Cavanagh & Williams, 1982; I. Hunter & Smith, 2007; Moore et al., 2012; Van Oeveren
et al., 2019). The higher energy consumption with imposed high SF can be explained by
the higher costs to move the limbs (e.g., internal work) (Cavagna & Kaneko, 1977),
whereas low SF may increase the work done to move the BCoM (e.g., external work).
Cavagna et al. (1991) suggested that SF at a given speed is chosen as a compromise
between minimising average power over the step (high SF) and the average power over
the positive work phase (propulsion-average power) (large SL). On this account, the
average power would be limited by the oxygen uptake or aerobic power, while the
propulsion-average power would be limited by the anaerobic capacity. In practice, part
of the work done to move the limbs can be (re)used to move the BCoM (Willems et al.,
1995). Therefore, the demarcation between internal and external work is complex to
establish with high precision. The possibility to transfer the energy of previously
initiated limb movements (kinetic and potential energy) between subsequent phases
implies that high or low SL/SF ratios may not necessarily indicate inefficiency. Since
both high and low SF’s resulted in an increased aerobic energy consumption, the limits
may not only be determined by the aerobic and anaerobic power production, but the
efficiency at a certain SL/SF ratio may also depend on the individuals’ ability to store
and reuse the energy that is not directly used to propel the BCoM. Individual prefer­
ences may thus depend on the reuse of work done to move the limbs and the efficiency
with which the runner can generate propulsive bursts during the short tstance.

Theoretically the SL/SF ratio reflects the proportion of the work done to move the
limbs relative to the work done to accelerate the BCoM directly and provides crucial
information about the BCoM trajectory. To interpret the SL/SF ratio, running speed
should be taken into account. Moreover, the shift in SL/SF ratio with speed may reveal
individual limitations and strengths. Even though experienced runners are likely to have
energetically optimised their SL/SF ratio, differences in running styles between experi­
enced runners still exist. The SL/SF ratio has limitations when it comes to describing the
running style. Imagine two runners of similar stature running at the same speed with the
same SF. Both can have distinctive running styles in that one may be running with a short
tstance + long tflight, and the other may be running with a long tstance + short tflight. We can

SPORTS BIOMECHANICS 7

conclude that the SL/SF ratio by itself is insufficient to fully describe a running style, and
additional parameters are thus required. The possible variations in the ratios between
tstance and tflight may explain the mixed and scarce evidence for a direct relationship
between SF and injury incidence, performance and experience.

**Stance phase and flight phase**

Once the SL/SF ratio has been defined, a logical next step in characterising the sinusoidal
BCoM trajectory is to determine the vertical position around which the BCoM oscillates
(Figures 1 and 2). This can be accomplished by subdividing one step into a stance and a
flight phase. These phases split the step horizontally, along the time axis, into tstance and
tflight and vertically, along a distance axis, into VDstance and VDflight. The ratio between the
stance and flight phase allows estimating vertical stiffness (Appendix, Equation 16–23).

_**Stance time**_

The time component tstance is in itself relevant since a runner can only produce forces
to propel the BCoM during the stance phase. For running speeds between 8 and 20 km/
h, tstance has a strong negative curvilinear relation with speed with values typically
ranging between 0.34 and 0.18 seconds (Carrard et al., 2018; Chapman et al., 2012;
Clark & Weyand, 2014; Concejero et al., 2013; Dorn et al., 2012; Forrester & Townend,
2015; García-Pinillos et al., 2018; Hoyt et al., 2000; Nummela et al., 2007; Pavei et al.,
2017; Roche-Seruendo et al., 2018; Da Rosa et al., 2019; De Ruiter et al., 2016; Weyand
et al., 2000) (Figure 3). Due to the reduction in tstance with increasing speed, the GRF
curves are compressed along the time axis, with increased force amplitudes to attain a
sufficient impulse to maintain speed (I = ∫(F∆t) (Clark & Weyand, 2014; Dorn et al.,
2012; Hamner & Delp, 2013; Nummela et al., 2007; Weyand et al., 2000). Weyand et al.
(2010) concluded that running speed is limited by the ability to generate the forces
required to attain the running speed during a short tstance, not by the maximum force
that the runner can exert on the ground. If a runner’s force production is limited, as
Weyand et al. (2000), (2010) suggested, then tstance should be regarded mainly as a
consequence of running speed where the horizontal velocity of the BCoM above the
ground limits tstance. Especially in attaining sprinting speeds (~25 km/h), the ability to
generate forces during short stance times seems to be the limiting factor.

Nummela et al. (2007) stated that the ability of fast force production is essential for
both running economy and attaining high maximal speeds, and that tstance is the only
factor directly related to both running economy and maximal running speed. In con­
formation of this claim, it was found that experienced sprinters have shorter tstance than
less experienced runners while running at the same speeds (Chapman et al., 2012; Clark
& Weyand, 2014; Cunninghan et al., 2013). However, within an 8–20 km/h speed range
tstance did not yield significant differences between runners of different performance
levels (Gómez-Molina et al., 2017; Preece et al., 2018; Da Rosa et al., 2019).
Interestingly, these studies found significant differences in tflight and effective tstance.
The term ‘effective’ in this context refers to the part under the GRF curve where the
vertical GRF exceeds the force required to support the body weight (Figure 2). Overall, it
seems that tstance is relatively constant across performance levels up to speeds of 20 km/h,

8 B. T. VAN OEVEREN ET AL.

while individual differences in tstance may be observed at higher speeds, possibly due to
the inability of lesser runners to generate high braking and propulsive forces within a
short time.

Consistent with the findings of Nummela et al. (2007), also other studies showed
that shorter tstance corresponded to a better running economy in mixed groups of
runners (Folland et al., 2017; Tam et al., 2018). One study even found a high correla­
tion between tstance and running economy in a group of elite female runners, but in this
study the effects of speed were ignored, which obscures the interpretation of this result
(Mooses et al., 2018). In contrast, within a group of elite runners, no differences in
tstance were found despite differences in running economy (Santos-Concejero et al.,
2017). Within a group of habitual runners running at 14 km/h, longer tstance was even
associated with a better running economy (Di Michele & Merni, 2014). These mixed
results with regard to the relation between tstance and running economy may reflect
individual differences in muscular properties.

There are only a limited number of studies in which tstance is corrected for body size.
Yet, the relation of leg length with the time component tstance is not difficult to under­
stand. At a given (horizontal) speed, tstance can be derived from the horizontal distance
covered by the BCoM during the stance phase (tstance = dstance · vx, Appendix, Equation
6). Imagine a long-legged runner with the same hip angle at touch-down and take-off as
a short-legged runner. At the same speed, the horizontal distance covered by the BCoM
distance during the stance phase of the long-legged runner will be larger and tstance will
be longer than in the short-legged runner (Whitcome et al., 2017). Since this relation­
ship between leg length and tstance is linear, tstance can be expressed as a ratio of leg
length (L0/tstance). Alternatively, Chapman et al. (Chapman et al., 2012) normalised
tstance to standing height instead of using leg length. Preece et al. (2018) used the
conventions provided by Hof (1996), which entail dividing tstance by √(L0/g)
(Appendix, Equation 10). Both methods allow interindividual comparisons with regard
to running style, but the method of Hof (1996) might be more correct from a mechan­
ical point of view. Note that, for a given speed and after correction for leg length, the
residual interindividual variation in tstance is relatively small and possibly hard to
quantify or modify voluntarily.

_**Flight time**_

Some runners seem to hardly touch the ground, while others appear to have difficulty to
become airborne. Indeed, marked differences exist in the time component tflight between
runners. For example, high-performance runners distinguish themselves from recrea­
tional runners by having longer tflight at given speeds (García-Pinillos et al., 2019; Padulo
et al., 2012; Preece et al., 2018; Da Rosa et al., 2019). Chapman et al. (Chapman et al.,
2012\) found shorter tflight in female than male runners. The same was found by Barnes et
al. (2014), who also found a strong correlation between tflight and running economy in
female runners, but not in male runners. Age may play a role as well, given that older
runners have shorter tflight than younger runners at given speeds (Cavagna et al., 2008;
Pantoja et al., 2016). Overall, there seems to be consensus that differences between
runners (performance, gender and age) are reflected in tflight.

SPORTS BIOMECHANICS 9

The manner in which tflight increases with running speed is described by a positive
curvilinear relationship (Figure 3) (Carrard et al., 2018; Concejero et al., 2013; GarcíaPinillos et al., 2018; Roche-Seruendo et al., 2018). Typically, tflight ranges between ~100 to
150 ms. Within 7 to 20 km/h, tflight is shorter than tstance. At high speeds, tflight seems to
reach a maximum (Dorn et al., 2012; Mann et al., 2015; Nummela et al., 2007; Pavei et al.,
2017; Roche-Seruendo et al., 2018; Da Rosa et al., 2019; Weyand et al., 2000). In
consequence, since tstance decreases as a function of speed, tflight exceeds tstance at ‘sprint’
speeds around ~25 km/h (Nemtsev et al., 2015; Weyand et al., 2000).

Once the runner is off the ground, the body behaves like a ballistic object.
Accordingly, due to the gravitational force, the BCoM describes a parabolic trajectory
(Blazevich, 2017). Therefore, common laws of ballistic motion can be applied to
estimate the vertical and horizontal displacement (VDflight and SL) during the flight
phase when tflight is known (Appendix, Equation 11–15). Given a constant gravitational
acceleration and assuming a constant force due to air resistance, the distance covered
during the flight phase (dflight) depends on the take-off angle (θoff), the velocity at takeoff, and the BCoM height at take-off relative to the height at touch-down (Blazevich,
2017; Ishimura & Sakurai, 2016; J. Hunter et al., 2004). Practically, this implies that
surface inclination and air resistance would influence tflight at least to some degree
(Padulo et al., 2012).

For a given speed, tflight depends predominantly on the take-off angle. Optimisation
of the take-off angle would result in a maximal flight distance. Take-off angle might be
even more informative than tflight as it both provides information on horizontal and
vertical displacement. Take-off angles have been calculated for sprint running (Cunha
et al., 2002; Ishimura & Sakurai, 2016) and the long jump (Bridgett & Linthorne, 2006).
Unfortunately, studies focusing on take-off (or touch-down) angles during constant
speed running are scarce. As far as we know, only one study calculated a ‘stride angle’
and found a strong correlation between this stride angle and running economy (SantosConcejero et al., 2017). It should be noted that since the angle was calculated as the
arctangent from step length and height (gtswing 2/8, Appendix, Equation 14), it seems
more appropriate to label it as ‘step angle’. Also, Garmin ® sports watches provide a
metric that reflects a push-off angle called vertical ratio (Garmin Ltd. or Subsidiaries,
2019). The vertical ratio is calculated by the ratio of VDstep and SL (Appendix, Equation
15). Theoretically, take-off angles, leg angles at toe-off or push-angles could provide
insight in both the vertical and horizontal displacement, but, as said, empirical studies
measuring take-off and touch-down angles are rare.

The interindividual differences in tflight and its associations with performance, RE,
gender and age indicate that tflight reveals essential information about running styles. A
longer tflight gives the runner time to move the legs forward, which reduces energy
consumption required for leg movements (internal work), especially at high constant
running speeds. In order to bring about a flight phase, the runner needs to generate a
force that at least exceeds the force required to support body weight. The flight phase
therefore reflects the runner’s ability to generate power during the relatively short tstance.
However, without insight into the forward displacement, a runner might as well be
jumping in place. When SL and tflight are analysed together, it becomes more likely that
different running styles can be distinguished.

10 B. T. VAN OEVEREN ET AL.

_**Vertical displacement**_

The BCoM of a runner oscillates within a range of approximately 6 to 10 cm (Da Rosa et
al., 2019; Gullstrand et al., 2009; Halvorsen, 2012). Imagine a runner who is running with
170 steps per minute. After one hour this runner might have displaced his or her BCoM
vertically by 1020 m. It is sometimes suggested that vertical displacement over a step
(VDstep) should be minimised to avoid unnecessary work against gravity (Saunders et al.,
2004). Indeed, running with exaggerated VDstep resulted in increased energy cost (Tseh et
al., 2008). However, a runner can reuse part of the potential and kinetic energy gained
during the flight phase in the subsequent landing (Cavagna et al., 1977). To this end,
energy is absorbed during the braking phase and returned during the propulsion phase,
which requires a certain VDstance. Furthermore, the vertical displacement during the
flight phase (VDflight) reduces the (internal) work needed to bring the leg forward. When
SF increases, VDstep typically decreases (Gullstrand et al., 2009; Slawinski & Billat, 2004).
The resultant VDstep is therefore not straightforward to interpret, and a runner cannot
simply minimise VDstep as is sometimes suggested (Adams et al., 2018).

It is well known that the BCoM does not oscillate symmetrically around an equilibrium
point. Further subdivision of VDstep into vertical displacement during stance (VDstance) and
flight phases (VDflight) is therefore necessary (Cavagna, 2006, 2009; Da Rosa et al., 2019).
Over a range of speeds, approximately 2/3rd of the VDstep occurs during tstance and 1/3rd
during tflight (Da Rosa et al., 2019). The VDstance/VDflight ratio is relatively stable, but not
constant over speeds. At low running speeds (~7-12 km/h), tflight increases more than tstance
(Carrard et al., 2018; Concejero et al., 2013; Gómez-Molina et al., 2017) and VDflight
accordingly increases more than VDstance (Cavagna, 2006, 2009; Cavagna et al., 2008; Da
Rosa et al., 2019; Slawinski & Billat, 2004). VDstep decreases thereafter between ~12 and
22 km/h, due to the rapid increase of SF relative to the SL (Gullstrand et al., 2009; Slawinski
& Billat, 2004). As a result, VDstance and VDflight combined reach a maximum VDstep
between 10 and 15 km/h (Chapman et al., 2012; Nummela et al., 2007; Da Rosa et al., 2019)
(Figure 3). Correspondingly, the vertical GRF has an inverted U-shaped relationship with
running speed (Schache et al., 2014; Weyand et al., 2000). Also, the energy cost has an
inverted U-shaped relationship with running speed, where the most economical running
speed was found at around 13 km/h (Black et al., 2018; Carrard et al., 2018). It is conceivable
that there is a direct association between VDstep and running economy that stems from the
balance between internal and external work. In that case, VDstep could, for example, be used
to determine the optimal marathon tempo and therefore a better understanding of VDstep
may result in some practical applications. In any case, it is clear that conclusions regarding
VDstep depend on the speed range measured, which explains some of the discrepancies in
literature on this topic. Furthermore, it is important for the interpretation of VDstep to
realise that substantial individual differences in the VDstep–speed relationship can be
expected since the speed at which VDstep reaches its maximum depends on both the
VDflight and VDstep.

VDstep in walking and running is the result of several interacting mechanisms, which
are explained by the spring-mass model and elaborations thereof. To what extent the
mechanisms play a role in the resultant VDstep strongly depends on running speed (see
Figure 4) and running style (Lee & Farley, 1998). VDflight is relatively straightforward to
understand since it results from the take-off angle and take-off velocity as discussed

SPORTS BIOMECHANICS 11

previously for tflight. VDflight results from the force generated during the stance phase
and therefore relates to VDstance. There are two mechanisms that explain VDstance
changes with speed. The inverted pendulum principle (Figure 4.a) predicts that the
BCoM reaches a maximum height at midstance. This geometrical increase of VDstance
plays an essential role in walking (Lee & Farley, 1998), but in running the BCoM
reaches its lowest point halfway the stance phase and its highest point during the flight
phase, which can be explained by adding spring properties to the model (Figure 4.b)
(Blickhan, 1989). The combination of the inverted pendulum model and the vertical
spring model is called the spring-loaded inverted pendulum (or SLIP) model. The two
mechanisms as combined in the SLIP model have opposite effects on VDstance. Other
mechanisms play a role as well. For example, in one model it was shown that the
translation of the CoP under the foot reduces VDstep when leg stiffness is not adjusted
accordingly (Bullimore & Burn, 2006). Additional effects in VDstep can be expected
from the BCoM landing-take-off height difference (Cavagna, 2006), partly effected by
the effect of leg retraction, that is, the backward rotation of the swing leg before initial
contact (e.g., Karssen et al., 2011, 2015; Seyfarth et al., 2003). Leg retraction is likely to
affect the BCoM height at initial contact (Figure 4.c), the duration of tstance and the
(related) leg stiffness.

**Figure 4.** The effects of various spring-mass model mechanisms on the vertical displacement during
the stance phase (VDstance). The contribution of the mechanisms (a-e) to the resultant VDstance (vertical
red bars) is speed dependent and varies between individuals. a) The inverted pendulum model
predicts that the BCoM will elevate during the stance phase. This elevation is relatively large with
longer stance times (tstance) as common at lower speeds. b) Typically, with longer tstance the CoP
translates from heel to toe (red dots). Such CoP translation affects the leg compliance and has been
found to contribute to a reduction of VDstance. c) The vertical spring stiffness (Kvert) predicts that the
leg-spring is loaded during stance phase and the BCoM is lowered during stance. d) The spring-loaded
inverted pendulum model (SLIP model) consisting of a combination of a and b. Changes in the leg
angle due to speed are taken into account, which allows the calculation of leg stiffness (Kleg). The
spring-leg is commonly defined by a straight line between the centre of pressure (CoP) and the BCoM.
Alternatively, bony landmarks (for example, the ankle joint to trochanter major) have been used to
define the spring-leg. Due to differences in, amongst others, the touch-down angle (θdown) and takeoff angle (θoff), the landing take/off does not occur symmetrically, resulting in a lower BCoM at the end
of the stance phase. e) The flight phase increases VDflight. While leg retraction in the final flight phase
increases the height of BCOM at landing.

12 B. T. VAN OEVEREN ET AL.

Lumping the effects of the inverted pendulum, the spring loading and the flight phase
on vertical displacement together in a single parameter (VDstep) renders its interpreta­
tion, let alone its manipulation (Adams et al., 2018; Eriksson et al., 2011; J. Hunter et al.,
2004), rather complicated. Since vertical displacement in running is partly explained by
the spring properties of the leg, further insight into stiffness is required to further clarify
the interpretation of vertical displacement.

_**Vertical stiffness**_

The spring properties of the muscle tendon complex are believed to play a crucial role in
the efficiency of running compared to walking. Therefore, the mechanics of the stance leg
are modelled as a spring. In general terms, a linear spring with a constant stiffness (k) will
produce a force (F) proportional to the displacement (y) from its equilibrium length,
which is known as Hooke’s law (-F = y. k, Appendix, Equation17).

It should be realised that in practice, it is difficult to distinguish cause and effect of the
variables in the linear spring model, especially when geometrical effects are taken into
account. To explain this further, a long tstance will geometrically result in a large excursion
of the inverted pendulum (Figure 4.a). In addition, a long tstance will, most likely,
correspond to a lower GRF when impulse is maintained. For a long tstance the lower
GRF and increased (upward) excursion of the inverted pendulum would result in a low
VDstance if we assume that the stiffness (k) is kept constant. The expected lower vertical
component of the GRF would thereby result in a reduced VDflight. A long tstance in
combination with a short tflight will therefore result in a low vertical displacement. There
seems to be consensus that better runners run with a relatively short tstance and long tflight
(García-Pinillos et al., 2019; Preece et al., 2018; Da Rosa et al., 2019). To generate
sufficient force for a flight phase it is necessary to ‘compress’ the leg spring. Therefore,
it is possible to observe more VDstance in better runners. If leg stiffness would be increased
a lower VDstance would be necessary to generate the same force. However, a higher leg
stiffness during running would also shorten tstance, thereby resulting in opposing effects
on VDstance due to less excursion of the inverted pendulum and a lower GRF. Overall, if
we take speed into account it seems that VDstep in better runners is more likely to be high
compared to less proficient runners. Any generic suggestions to minimise VDstep are
therefore dubious, in spite of the common assumption that VDstep should be minimised.

In accordance with the general linear spring formula two conventions provide the
basis for commonly used spring-mass models to calculate stiffness: vertical stiffness
(Kvert) and leg stiffness (Kleg) (Brughelli and Cronin, 2008b). Vertical stiffness is defined
as the ratio of maximal force to VDstance, (Kvert = Fmax/VDstance, Appendix, Equation 21)
(Farley & Gonzalez, 1996; Morin et al., 2005; Brughelli & Cronin, 2008a, 2008b). Leg
stiffness is defined as the ratio of the maximal force to the maximum leg compression
during the stance phase (Kleg = Fmax/∆L, Appendix, Equation 18, 22, 23) (Farley &
Gonzalez, 1996). Kvert changes substantially with running speed since the leg angle of
attack (Figure 4.d, θdown) is speed dependent. To overcome this problem, Kleg corrects for
the speed dependency by taking changes in effective leg length ∆L into account. Where
leg length is commonly defined as the distance between the centre of pressure and the
BCoM (see Figure 4 caption for further details). To estimate ∆L the horizontal distance
between BCoM and the point of initial contact are used dBCoM-ic = vx.tstance/2, Appendix,

SPORTS BIOMECHANICS 13

Equation 8). Notice that this correction takes the inverted pendulum principle into
account. With this correction Kleg is relatively stable across speeds (Arampatzis et al.,
1999; García-Pinillos et al., 2019; Morin et al., 2007). The difference between Kvert and
Kleg underscores the difference between stiffness when hopping in place and stiffness
during forward motion. For the estimation of the effective leg length in the Kleg models
there are additional issues to consider as noticed under the paragraph Vertical displace­
ment. The leg is placed under a steeper (closer to 90°) angle with the surface at initial
contact relative to take-off (Cunha et al., 2002; Maykranz & Seyfarth, 2014) and the knee
bends at initial contact (Lin et al., 2014). The effective leg length is further affected by the
excursion of the CoP under the foot (Bullimore & Burn, 2006; Morin et al., 2007). Also,
the CoP excursion and the effective leg length may change when runners tend to land
more on the fore-foot at higher speeds (Breine et al., 2014; Clark et al., 2014; Lai et al.,
2020). Lastly, pendulum effects of the segmented swing-leg on stiffness should be
considered (Clark et al., 2017; Kugler & Janshen, 2010; Maykranz & Seyfarth, 2014;
Rashty et al., 2014). Together, this would result in a complex model to estimate leg
stiffness. As far as we know, these issues have not been incorporated into a single model
to be tested across a range of speeds in various running styles. Nevertheless, faster
runners seem to have higher vertical stiffness (Barnes et al., 2014; García-Pinillos et al.,
2019; Da Rosa et al., 2019). In line with these results, experienced sprinters had less knee
flexion during the stance phase and a shorter tstance compared to middle- and longdistance runners at speeds from 11 to 21 km/h (Cunninghan et al., 2013).

The calculations for stiffness strongly depend on the ratio between tstance and tflight. In
addition, body mass, gravitational acceleration, leg length and running speed are taken
into account (Morin et al., 2005). Likewise, Duty factor (DF) is calculated as the ratio of
tstance over stride time (DF = tstance/(2 \[.\] tstance/(2 \[.\] (tstance+tflight)), Appendix, Equation 16)
(Blum et al., 2009; Forrester & Townend, 2015; Mann et al., 2014; Vernillo et al., 2017)
and therefore DF carries similar information as the stiffness models. DF is a convenient
measure to (visually) identify running styles as a short tstance with long tflight can be
visually verified by an observer. DF is further suitable for making interindividual
comparisons as it is a dimensionless ratio, and does not rely on many assumptions. In
walking, the stance phase is longer than half the stride time, and thus the DF exceeds 0.5.
In running, the DF decreases nonlinearly from 0.45 at very low running speeds to 0.28 at
~22 km/h (Forrester & Townend, 2015). For running speeds up to ~25 km/h the relation
tflight \< tstance holds (Carrard et al., 2018; Chapman et al., 2012; Concejero et al., 2013;
Dorn et al., 2012; Gómez-Molina et al., 2017; Hanley & Mohan, 2014; Mann et al., 2015;
Nummela et al., 2007; Pavei et al., 2017; Roche-Seruendo et al., 2018; Weyand et al.,
2000). A too low DF can be uneconomical given the high muscle activation during short
tstance, and a high DF may indicate wasteful mechanical work due to braking-propulsion
accelerations (Usherwood, 2016). For a constant mechanical spring, tstance would equal
tflight. In practice, tstance is not equal to tflight due to varying muscular forces during the
stance phase. Therefore, a more ‘symmetrical rebound’, in which tstance is closer to tflight,
is believed to indicate better usage of elastic properties of the muscular-tendon complex
(Cavagna, 2006, 2010). Consistent with this belief, better runners have shorter tstance and
longer tflight compared to less proficient runners (Concejero et al., 2013; Folland et al.,
2017; Da Rosa et al., 2019; Santos-Concejero, 2014). Folland et al. (2017) found that DF, a
minimal horizontal pelvis velocity (braking), shank touch-down angle, and trunk

14 B. T. VAN OEVEREN ET AL.

forward lean explained 31% of the variability in season-best times. In the same study,
running economy was for 39% explained by VDstance normalised to body height, mini­
mum knee flexion during ground contact, and minimum horizontal pelvis velocity
(Folland et al., 2017). Note that DF did not contribute significantly to the regression
model for running economy. However, minimum knee flexion and VDstance provide
information about vertical stiffness, just as DF does.

In sum, VDstep is an accessible parameter that is used in feedback applications and
scientific studies, but is difficult to interpret given that opposing effects are lumped into a
single parameter. Instead, the ratio between VDstance and VDflight provides insight into
the runner’s ability to exploit elastic properties during running. To this end, stiffness
parameters can be used. In order to categorise running styles with corresponding
motions, the DF may be more straightforward. However, DF alone is not sufficient to
distinguish two runners with the same stature that run in a different fashion, because
both a short tstance + short tflight and a long tstance + long tflight could theoretically result in
the same DF. Therefore, additional information about forward displacement is required,
which can be provided by SF (or SL) at a given speed.

**Landing/take-off asymmetry**

Up to this point, we have assumed that the BCoM follows a symmetrical sinusoidal path
during the stance phase, similar to a frictionless bouncing ball. However, it is known that
due to varying muscle activation, the landing/take-off does not necessarily occur symme­
trically in human running. The landing/take-off asymmetry may therefore provide addi­
tional information about variations in running styles. To this end, the stance phase is
subdivided into a braking (tbrake) and a propulsion phase (tprop) based on the sign change of
the horizontal GRF component (Figures 1 and 2). For a constant stiffness spring absolute
Fbrake equals Fprop and tbrake equals tprop. Assuming that the geometrical aspects remain
constant, a change in the tbrake/tprop ratio would imply that the runner changes the spring
properties of the leg by means of muscle activation. Just like when tstance and tflight were
equal as previously discussed, a more symmetrical landing/take-off may indicate that the
runner is making more use of the elastic ‘spring’ properties of the muscle-tendon com­
plexes (Cavagna, 2006, 2010). Since the impulse vectors during landing and take-off are
oblique to the surface, a landing/take-off asymmetry could be apparent in the horizontal
and vertical GRF amplitudes, or in the timing variables (tbrake vs tprop).

When a runner accelerates, the propulsion impulse exceeds the braking impulse (Van
Caekenberghe et al., 2013). At constant speed, ignoring air drag and friction, the braking
impulse and propulsion impulse cancel each other out, resulting in a zero-net change of
the horizontal velocity (Cavagna, 2010), i.e., ΔI ¼�ð � Fx _;_ brake � tbrakeÞ þ�ðFx _;_ prop �
tpropÞ ¼ 0 (Appendix, Equation 24). In constant speed running up to ~14 km/h, tbrake \<
tprop. The average GRF during propulsion is thus lower than during braking at these
speeds, which is compensated by a longer tprop. At higher speeds, tbrake approaches tprop,
mostly because tprop becomes shorter (Cavagna, 2006, 2010; Da Rosa et al., 2019). The
horizontal force and time are therefore coupled in constant speed running. For example,
reducing tbrake will coincide with an increased amplitude of Fx _;_ brake. Alternatively, a
runner with a large Fx _;_ brake and without changes in tbrake will require a larger propulsion

SPORTS BIOMECHANICS 15

impulse to maintain a constant speed. The landing-take-off asymmetry is more pro­
nounced in older than younger runners (Cavagna, 2010; Cavagna et al., 2008) with a
longer tprop in older runners and consequently longer tstance (Agresta et al., 2018; Cavagna
et al., 2008; Pantoja et al., 2016). In accordance with the asymmetry in timing, the leg
angle at push-off is steeper (inside angle) than at touch-down angle (Figure 4.c), and the
BCoM height at take-off is higher compared to touch-down height (Cavagna, 2010;
Cavagna et al., 2008). Maykranz and Seyfarth (2014) were able to mimic the asymmetry
of human running by introducing the foot segment with an ankle extension into the SLIP
model. The ankle extension resulted in a change of effective leg length, which partly
explains the landing/take-off asymmetry. Potentially, the long tprop in older runners
compensates for a reduced force-generating potential and diminished elasticity of the
muscle-tendon complex and can be regarded as a useful strategy to cope with individual
limitations. However, Da Rosa et al. (2019) found no significant differences in tbrake and
tprop between two groups divided by 3000 m performances suggesting that tbrake and tprop
are not sensitive to discriminate between running performances.

The landing/take-off asymmetry should be visible in GRF traces. Instantaneous
changes in GRF may change braking and propulsion impulse and contribute to land­
ing/take-off asymmetry. Many studies on GRF focus on foot strike patterns (rear/mid/
forefoot) or shod versus barefoot running. Most studies have focused on the vertical
component only. The prevailing view is that a rearfoot striking pattern creates a char­
acteristic first peak in the GRFy (Kluitenberg et al., 2012; Nordin et al., 2017; Vernillo et
al., 2017). Studies have shown that at high SF (or short tstance) the amplitude of the initial
peak in the GRFy was reduced (Giandolini et al., 2013; Thompson et al., 2014). In some
cases, the increased SF also resulted in skewing of the GRFy towards the first half of the
stance phase (Farley & Gonzalez, 1996). However, similar impact peak forces were also
found at high running speeds in the absence of a rearfoot strike pattern (Bezodis et al.,
2008; Bundle & Weyand, 2012; Clark et al., 2017; Clark & Weyand, 2014; Weyand et al.,
2010). Clark et al. (2017) were able to accurately predict GRFy curves over a wide range of
speeds for both rear- and fore-foot striking patterns. They concluded that sprinters
attained faster top speeds than non-sprinters by applying greater vertical forces during
the first half of the stance phase. These greater forces led to skewing of GRFy towards
early stance that increased with speed (Clark et al., 2017; Clark & Weyand, 2014). Similar
instantaneous peaks and valleys as in GRFy during early stance are also observed in the
GRFx traces (Giandolini et al., 2013; Munro et al., 1987; Thompson et al., 2014). It seems
that rearfoot (Boyer et al., 2014; Nordin et al., 2017) and forefoot strike patterns
(Giandolini et al., 2013; Munro et al., 1987; Thompson et al., 2014) can be recognised
from the GRFx (Figure 5). Closer examination reveals that instantaneous changes are
present in both GRFx and GRFy, which can be explained by changes in GRF orientation
(Boyer et al., 2014; Nordin et al., 2017). Unfortunately, studies in which the horizontal
and vertical GRF components are combined into a single vector are rare, which has been
addressed previously as a limitation of the current literature (Boyer et al., 2014; Chang et
al., 2000; Haugen et al., 2019; Moore et al., 2016). It is therefore difficult to draw strong
conclusions on the need to define landing/take-off asymmetry to identify various running
styles. Further research on the association between landing/take-off asymmetry and
instantaneous GRF changes in relation to foot strike patterns and in fact whole-body
kinematics is warranted.

16 B. T. VAN OEVEREN ET AL.

a) b) c) d) e)

**Figure 5.** Examples of variations in GRF curves, the vertical GRF in orange and the horizontal GRF in
blue. The dotted lines represent uncertainty. a) During downhill running and the step before a hurdle,
the braking impulse vector becomes oriented more horizontally while the propulsion impulse vector
becomes oriented more vertically (both visualised as grey to the black arrow). In contrast, during
constant speed running the braking impulse should roughly equal the propulsion impulse; b)
Increased tprop during low speeds and in older runners; c) Typical curve of rearfoot striking pattern;
d) Typical curve of forefoot striking pattern; e) The first peak in sprint running and skewness towards
early stance. Due to running with increased SF, the first vertical peak may not be apparent.

In conclusion, the vertical and horizontal GRF curves cannot be assumed to be
symmetrical and the asymmetry is speed dependent. Therefore, without taking running
speed into account, the duration of both tbrake and tprop, or GRFx in relation to GRFy,
interpretations regarding injury risk or performance may not be valid. Therefore, high
impact peak forces and steep slopes should not necessarily be interpreted as ‘wrong’ as
some authors seem to imply (e.g., Bredeweg et al., 2013; Napier et al., 2018). The landing/
take-off asymmetry was more pronounced in older runners compared to younger
runners, but not in groups divided by 3000-m performances. It should be noted that
these studies yielded significant differences in tflight, tstance and SL (Cavagna et al., 2008;
Preece et al., 2018; Da Rosa et al., 2019). Presumably, inter-individual differences in
landing/take-off asymmetry are, at least partly, reflected in other parameters. For exam­
ple, it can be hypothesised that tprop relates with tflight. If so, landing/take-off asymmetry
does not need to be measured in addition to the SF and DF to discriminate running
styles. However, this issue should await further research to be decided.

**Limb and trunk kinematics**

The BCoM movements mechanically interrelate with limb and trunk kinematics. It is
useful to understand the relationships between the BCoM movements and limb and
trunk kinematics, because this may help to distinguish running styles and provide insight
on why, where and how to make modifications in a running style.

_**Leg configuration at initial contact**_

The leg configuration at initial contact, which is characterised by hip, knee and ankle
joint angles, determines the anterior foot placement distance relative to the BCoM
(Figure 6). The position of the CoP relative to the BCoM and hence the anterior foot
placement distance is crucial for the effects of the GRF vector on the BCoM trajectory.
Excessive anterior foot placement relative to the BCoM is commonly referred to as
‘overstriding’. A far anterior foot placement at initial contact results in higher braking

SPORTS BIOMECHANICS 17

impulses (Lieberman et al., 2010, 2015). The large moment arm of the GRF to the knee
joint will force the knee into extension, or require high flexor moments around the knee
(Lieberman et al., 2010, 2015). When the point of force application is located behind the
ankle joint, the dorsiflexor muscles will be loaded eccentrically, potentially increasing the
risk of tibial stress syndrome.

**Figure 6.** Geometrical relation for various leg configurations (a-e) and the horizontal distance between
the hip and initial contact (length of the horizontal bars, dhip-ic). This anterior foot placement position
at initial contact (dhip-ic) can be estimated from tstance at a given horizontal speed of the hip, or
alternatively, the BCoM. These figures visualise that dhip-ic, and thus tstance, relate to hip and knee
angles. The ankle angle (green wig) is kept constant in these figures and is expected to provide a
relative limited contribution to the hip height and dhip-ic. Notice that runners with an average tstance
are expected to have the most knee flexion at initial contact.

At higher speeds, the foot is placed more anterior (Cunninghan et al., 2013). It is
believed that the more anterior foot placement is most likely the result of hip flexion
(Figure 6.a to 6.c) rather than knee extension (Figure 6.a to 6.b) (Orendurff et al., 2018).
Accordingly, runners with larger SL (resulting in higher speeds) showed more hip
flexion, but not more knee extension at initial contact (Lieberman et al., 2010). Better
runners land less anterior to their BCoM despite their larger SL (Preece et al., 2018). Also,
sprinters land less anterior relative to their BCoM than non-sprinters (Bushnell &
Hunter, 2007; Cunninghan et al., 2013). Such larger SL’s are possible by increased flight
times, giving the runner time to position his or her leg before landing. Therefore, large SL
should not be confused with ‘overstriding’. Instead, ‘overstriding’ likely relates to a
relatively long tstance as previously discussed and potential effects of speed should be
considered.

Less anterior foot placement (Figure 6a,b) can be achieved by leg retraction (rearward
leg rotation) before initial contact. Leg retraction occurs mostly by rotation of the leg
around the hip (Orendurff et al., 2018). As a result of leg retraction, the swing foot orients
more normal-to-the ground before initial contact, the hip/BCoM is higher at initial
contact, and tstance is shortened. The leg retraction decreases the horizontal velocity
difference of the foot relative to the surface (‘matching ground speed’) (Blazevich,
2017; Blum et al., 2010), which reduces impact impulses, prevents slipping (Karssen et
al., 2015) and improves stability (Blum et al., 2010; Karssen et al., 2011; Seyfarth et al.,
2003). As a consequence, it is expected that leg retraction redirects the GRF vector more

18 B. T. VAN OEVEREN ET AL.

vertically during early stance and that the vertical impact peak shifts towards early stance
as observed in experienced sprinters (Clark & Weyand, 2014). According to Karssen et al.
(2011), on a predictable terrain (such as a road or track) the runner can adopt a running
style with fast leg retraction to deal with impact losses, impact forces, the risk of slipping
and (internal) stability. However, to cope with terrain irregularities other requirements
are needed. On uneven terrain, the runner may adopt a running style optimised for
disturbance rejection. Disturbance rejection is the ability to follow a given trajectory in
spite of unexpected external forces (Karssen et al., 2011). Their conclusions suggest that
to control stability the leg retraction speed can be optimised to enhance robustness to
internal (leg stiffness variations) or external disturbances (ground surface irregularities).

Knee angle at initial contact can vary within a range of anterior foot placement
positions and with a given hip angle (Figure 6c,d). Knee flexion angles at initial contact
were found to correlate with the maximal knee flexion later in stance phase (r = 0.67)
(Derrick, 2004). Studies have shown that knee flexion during the stance phase reduces
vertical peak leg acceleration and GRFy (Derrick, 2004; Orendurff et al., 2018). Therefore,
knee flexion might be regarded as a strategy to absorb the landing impact and might also
help to improve disturbance rejection. The strategy to land with bent knees will load the
quadriceps muscles eccentrically (Hamner et al., 2010), which may induce muscle
sourness when excessive knee flexion moments are present. Since knee flexion can be
used to control the leg stiffness, it can be expected that knee flexion is speed dependent.
However, evidence regarding knee flexion changes during the stance phase in relation to
running speed is equivocal, with some studies indicating increased knee flexion during
midstance (Grimmer & Seyfarth, 2014; Orendurff et al., 2018) and others showing knee
flexion to remain relatively stable across running speeds (Cunninghan et al., 2013).

Besides hip and knee angles, the runner can control ankle angles. As previously noted,
foot strike patterns have drawn substantial scientific attention. However, it should be noted
that the orientation of the foot mostly depends on the orientation of the lower leg. Ankle
plantar or dorsal flexion will only contribute to a small extent to dhip-ic or hip height. Where
dhip-ic is the anterior foot placement position at initial contact relative to the hip.
Furthermore, the neuromuscular control occurs from proximal to distal (Orendurff et al.,
2018), which makes striking patterns a consequence, rather than a cause of leg retraction.
Therefore, despite the vast body of literature on foot strike patterns, we argue that foot
strike patterns should not be regarded as a key feature of running styles.

For leg stiffness, we have discussed how tstance is geometrically related to leg config­
uration (landing/take-off angle). Since also hip height depends on tstance, it is safe to
assume that leg configurations relate (at least partly) to tstance. Furthermore, tflight will
change inversely proportional to tstance for a given SF. Therefore, it is safe to assume that
based on the tstance/tflight ratio (or DF), SF and speed, predictions on leg configuration can
be made.

_**Trunk flexion-extension**_

Another salient characteristic of an individual’s running style is the degree of forward, or
backward trunk lean. Running with consistently increased trunk inclination is sometimes
advocated as it results in higher SF and reduced VDstep (Dallam et al., 2005). However,
between 12 km/h to 20 km/h, recreational runners show trunk inclinations ranging

SPORTS BIOMECHANICS 19

between 5° and 7.5° (Preece et al., 2016), whereas, over the same speed range, elite
runners maintain a smaller consistent thoracic inclination of around 3° (Preece et al.,
2016). Accordingly, a more upright trunk posture appears to be correlated with better
running performance (Folland et al., 2017). In addition, novice runners being in a
fatigued state increased trunk peak flexion and decreased peak extension, resulting in
an overall increase in trunk inclination (Koblbauer et al., 2013; Maas et al., 2018). Dos
Santos et al. (2016) instructed participants to run with exaggerated forward trunk lean
angles (normal 9°, experiment 15°) and found that runners placed their foot more
anterior at initial contact. In walking, exaggerated forward trunk lean led to a posterior
shift of the hip relative to the BCoM, a steeper leg touchdown angle and a steeper leg toeoff angle (Aminiaghdam et al., 2017). Also in sprinters the trunk lean angle strongly
correlated with the anterior foot placement position (Cunha et al., 2002). In walking as
well as sprint running, the forward trunk inclination was associated with a more forwardtilted GRF vector (more vertical during tbrake and more horizontal during the tprop)
(Aminiaghdam et al., 2017; Van Caekenberghe et al., 2013). By bringing the head, arms
and trunk forward, a runner reduces the anterior BCoM position (according to an
estimate by Santos by ~2–3 cm) relative to the CoP. It is possible that forward trunk
lean plays a role in compensatory strategies to maintain anterior-posterior balance or to
increase forward propulsion despite more anterior foot placement, but it is questionable
if this should generally be advised.

Within a step, the trunk flexes and extends. This dynamic trunk flexion-extension
plays a role in compensating the angular momentum in the sagittal plane generated by
the legs (Hinrichs, 1987). However, the contralateral leg movement compensates most of
the angular momentum and the trunk flexion-extension only partly compensates the
angular momentum generated by the legs in the sagittal plane (Hinrichs, 1987). During
the stance phase, trunk flexion reaches its peak around midstance while extension occurs
during propulsion (Koblbauer et al., 2013; Teng & Powers, 2014). During the flight phase
the trunk flexion-extension range remains relatively small. The trunk flexion-extension
may therefore predominantly affect the timing and redirection of the propulsion force. It
can be hypothesised that high or late propulsive forces during late stance coincide with
large trunk extension moments. The acceleration of the swing leg can also promote
horizontal propulsion (Kugler & Janshen, 2010; Kyrolainen et al., 2001; Schmitz et al.,
2014). Therefore, insufficient swing leg velocity may be associated with more trunk
extension during late push-off. Perhaps larger trunk flexion-extension range and a longer
tprop observed during acceleration and in fatigued runners, novice runners, and older
runners may serve the same purpose: to maintain propulsion impulse without peak force
generation.

It is possible that increased consistent trunk inclination may result from a different
movement strategy compared to a running style with increased dynamic trunk
flexion-extension moments. An increased trunk inclination seems to increase SF,
whereas increased trunk flexion-extension moments rather seem an attempt to
increase propulsive forces and are therefore more likely to stimulate SL instead of
SF. However, a high SF may not only be associated with increased trunk inclination
since a too upright trunk posture may also result in higher SF. For example, a higher
SF could also result from a too vertical oriented push-off force. Based on these
speculations regarding trunk posture, the association between running with increased

20 B. T. VAN OEVEREN ET AL.

trunk lean, an upright trunk posture and with exaggerated trunk flexion-extension
with spatiotemporal parameters can be usefully investigated in future studies. Based
on the studies discussed above, we expect trunk posture to be associated with vertical
displacement, landing/take-off asymmetries and take-off angles.

_**Body torsion and arm swing**_

Notable differences in body rotation and arm swing can also be observed between
runners. In running, the lower body (legs and lower trunk) and upper body (upper
trunk, head and arms) rotate in opposite directions about the longitudinal axis, with
opposite vertical angular momenta (Hamner & Delp, 2013; Hinrichs, 1987). The vertical
angular momentum generated by the lower body needs to be compensated to prevent
whole-body rotation resulting in a non-straight trajectory. In runners generating insuffi­
cient compensatory angular momentum using the upper body, longitudinal rotation of
the upper body may be visible (Pontzer et al., 2009) with the hands tending to cross the
body’s midline (Strohrmann et al., 2013). At higher running speeds, the more rapid leg
movements increase the angular momentum of the lower body (Hamner & Delp, 2013).

The lower body angular momentum is the result of various (related) factors in the gait
cycle.

1. At initial ground contact, the braking force decelerates the hip relative to the midline,
   thereby creating a change in angular momentum (Arellano & Kram, 2012). For a given GRF
   a larger step width, or a wider pelvis, will theoretically increase the change in angular
   momentum, which may partly account for individual differences.

1. During the stance phase, the legs swing in the opposite direction constituting an angular
   momentum around the longitudinal axis (Hinrichs, 1987). This angular momentum will be
   greater when the mass of the leg is further away from the hip, and when the velocity of the
   leg is higher.

1. During late push-off, transverse plane pelvic rotation lengthens the step (‘pelvic step’),
   thereby increasing the angular momentum around the longitudinal axis (Bruijn et al., 2008;
   Preece et al., 2016).

Given the effect of these factors, whole-body rotations, which are commonly seen in
runners, are potentially the result of running styles with anterior placement, or emphasis
on push-off (e.g., large propulsive force during late stance, or long tprop). Especially
during the flight phase in the absence of free moments, the upper body including the
arms provides the principal source for generating compensatory angular moments
(Hinrichs, 1987). The pelvic and thoracic contributions to total body angular momentum
are relatively small since masses of these segments are distributed close to the long­
itudinal axis (Bruijn et al., 2008; Hinrichs, 1987). More importantly, high accelerations of
the arms cause substantial compensatory moments (Hamner & Delp, 2013; Pontzer et al.,
2009). Also, the downward acceleration of the pendular arm swing provides a small (less
than 10%), but meaningful contribution to the vertical GRF. In fact, despite the addi­
tional energy required to swing the arms back and forth, arm swing reduces the net
metabolic (energy) cost of running (Arellano & Kram, 2011). The role of the arms in
generating compensatory moments becomes even more critical when the swing time
decreases, as occurs at high running speeds (Hinrichs, 1987).

SPORTS BIOMECHANICS 21

Besides compensation using the upper body, the runner can prevent whole-body
rotation by generating a substantial exorotation moment around the hip at the
stance-leg side. These, ‘free moments’ are transferred over the knee (most likely
via passive tissues), which may explain why such free moments have been found to
correlate with tibial stress (Milner et al., 2006; Pohl et al., 2008) and knee injuries
(Willwacher et al., 2016). Large free moments may also place a high demand on the
rotator muscles of the hip. Reducing the net angular momentum about the vertical
axis generating angular moments using the upper body may therefore help to reduce
injury risk.

The relationship between the spatiotemporal parameters and vertical angular moment
is not straightforward, given the multiple potential causes for lower body rotation and
various compensatory mechanisms. A longer tstance is associated with more anterior foot
placement and thereby presumably results in larger braking forces. A longer tstance will
also relate to more pelvic rotation. Furthermore, given the effects of the downward arm
swing on the vertical GRF it possible that, especially at high running speeds, a short tflight
may be indicative of an ineffective arm swing with potentially more upper body rotation.
Therefore, runners with long tstance and short tflight are more likely to suffer large lower
body angular moments or are unable to sufficiently compensate lower-body rotations
with upper body angular moments.

_**Leg swing**_

The leg of a runner of 70 kg weighs around 12 kg (Plagenhoef et al., 1983). With SF
somewhere between 160 and 190 spm (Van Oeveren et al., 2017), the swing leg moves within
1/3th of a second from its most anterior to its most posterior position. Modica and Kram
(2005) estimated that swinging the legs requires ~20% of the net energy cost of running at
11 km/h. Later this estimation was adjusted to ~7% due to synergistic movements to
accomplish vertical body weight support, forward propulsion and leg swing (Arellano &
Kram, 2014; Chang & Kram, 2017). This adjustment highlights the effective contribution
achieved by the swing leg kinematics and kinetics to both vertical and horizontal propulsive
forces. One of the potential mechanisms explaining this efficiency is that the kinematic energy
of the swing leg can be temporarily stored in elastic structures, such that it is not lost, but can
be reused in subsequent movements. For example, Preece et al. (2018) found that, compared
to less proficient runners, high-performance runners had more flexed knees during swing,
but without differences in knee angles at initial contact. This finding suggests that highperformance runners have higher knee extension velocity during late swing. During late
swing, the hamstrings absorb the kinetic energy, such that it reaches a maximum just before
initial contact (Chumanov et al., 2012). The tension increase on the hamstrings can be
regarded as a mechanism to reuse the kinetic energy of the swing leg, and contributes to
the subsequent leg retraction (Morin et al., 2015). With a potential downside of increased
hamstring injury risk (Hoogkamer et al., 2017; Kenneally-Dabrowski et al., 2019; Schache et
al., 2013; Sun et al., 2015).

A second mechanism to potentially improve the efficiency of the swing leg is by
reducing its moment of inertia. Running with extended legs has been shown to hinder
the hip flexors from propelling the leg quickly forward due to the associated changes in
the moment of inertia of the swing leg (Williams et al., 1987). Accordingly, experiments

22 B. T. VAN OEVEREN ET AL.

with weights (up to 2 kg) distally placed on the legs and with heavy shoes showed that
energy consumption is affected by the distribution of limb mass and resulted in lower
SF’s (Breine et al., 2017; Martin, 1985; Myers & Steudel, 1985; Reenalda et al., 2016). Since
both legs move in phase, a faster leg swing will be associated with a shorter tstance of the
contralateral leg. Therefore, in order to attain high running speeds, during which SF is
high and tstance is short, it becomes critical to sufficiently flex the knee during the swing
phase (Hamner & Delp, 2013; Lipfert, 2010; Willems et al., 1995).

The swing leg motion is often ignored in SLIP models as they essentially describe the
course of one step (technically a half-cycle). Rashty et al. (Rashty et al., 2014) showed that
by modelling the pendular motion of the swing leg in the conventional SLIP model, the
generated momentum of the swing leg induces sequential steps. Consequently, the
forward motion becomes more stable, which led the authors to suggest that the swing
leg may help to reduce muscular force provided by the stance leg (Rashty et al., 2014).
The swing leg reaches its highest forward acceleration during the stance phase of the
contralateral leg (Figure 2, d). Understandably, the leg swing contributes to the genera­
tion of propulsive forces (Kyrolainen et al., 2001; Schmitz et al., 2014). For example, an
asymmetrical angular acceleration of body segments results in a forward-oriented GRF.
A high acceleration of the lead leg at the end of the propulsion phase may consequently
orient the GRF more horizontally, resulting in a change in whole-body angular momen­
tum and more effective propulsion (Kugler & Janshen, 2010).

Runners with high SF and short tstance can be expected to have higher knee flexion
during the swing phase. Notably, tstance can be shortened due to more leg retraction
before initial contact or by reducing tprop. A long tprop may delay and reduce swing knee
flexion, which increases the moment of inertia. During mid-swing, a faster leg swing will
stimulate a shorter contralateral tstance and contribute to generate propulsive forces. A
relatively long tflight may increase the time to flex the knee and retract the leg. All in all, we
expect knee flexion to be reflected in the spatiotemporal parameters of interest.

**The dual-axis framework**

The characteristics of the BCoM are used in this review to identify the key parameters
that define running styles. To fully describe the spectrum of running styles we argue that
it is required to cover at least the horizontal and vertical component of the BCoM
trajectory. The SF (or SL) and stance/flight ratio at a given speed seem to provide the
necessary information. Given the possibility to vary the stance/flight ratio at a given SF or
vice versa, the isolated analysis of these key parameters may not convey an unambiguous
image of a running style. In addition, as stipulated, these ratios are likely to explain part
of the limb and trunk kinetics and kinematics. Given the speed-dependency of all
parameters considered in this review, a running style should be defined at a given
speed. As a guideline for identifying running styles and interpret biomechanical para­
meters in running we propose the use of the conceptual Dual-axis framework (Figure 7)
as explained in detail in the next section.

The vertical position in the Dual-axis framework is quantified by the tstance/tflight ratio.
To prevent division by zero in the absence of a flight phase (as in walking), it is
recommended to use the DF instead. The vertical position can be expected to be most
directly related to running performance, since numerous studies have shown that a short

SPORTS BIOMECHANICS 23

tstance, long tflight, low DF or high stiffness, relates to performance (e.g., Concejero et al.,
2013; Folland et al., 2017; Da Rosa et al., 2019; Santos-Concejero, 2014). The tstance/tflightaxis reflects the utilisation of elastically stored energy. To achieve the highest speed
possible, a running style enabling the delivery of high propulsive forces over a wider
speed range would be preferred, which the runner can achieve by reusing elastically
stored energy. Hence this running style is labelled as ‘Bounce’ and is characterised by a
short tstance and a relatively long tflight. Both VDstance can be expected to be large to enable
the generation of high forces and as a result VDflight can also be expected to be relatively
large.

**Figure 7.** Visualisation of the proposed Dual-axis framework to characterise the fundamental differ­
ences in running styles as assessed at a given speed. The horizontal axis is defined by SF corrected by
leg length and signifies the forward BCoM displacement per step. With at the left a high SF and at the
right a low SF. The vertical axis represents the ratio between the stance and flight phase, which is
quantified by the DF. With at the top a running style having a low DF. Together the axes describe a
continuous spectrum of running styles with on the extremes ‘Walk’, ‘Bounce’, ‘Hop’, and ‘Push’ styles.
Based on the horizontal distance between initial contact and the hip, a running style labelled ‘Sit’ is
positioned in the centre, which is characterised by a flexed knee at initial contact. The curved orange
arrow at the top indicates the expected effect of running speed on the interdependency between DF
and SF.

24 B. T. VAN OEVEREN ET AL.

In contrast, the running style at the low end of the vertical axis, coined ‘Stick’, is
characterised by a long tstance with a short tflight. The associated low VDstep can be
beneficial at low running speeds, or in conditions in which high vertical peak forces
are unbeneficial (such as while running with a heavy bag or in loose sand). With
increasing speed, tflight increases relative to tstance, but plateaus around ~20 km/h
(Figure 3). In the Stick, this plateau can be expected to occur earlier, because the ability
to generate propulsive forces during the short tstance may limit some runners to increase
tflight further.

The horizontal position in the Dual-axis framework for a given speed is determined by
either SF or SL. Note that both SF and SL can be chosen given their inverse relationship
with speed. With a large SL/low SF on the right side and small SL/high SF on the left side.
The position of a runner on the horizontal axis strongly depends on the runner’s ability
to generate propulsion forces. Since taller runners naturally have larger SL, normalisation
to leg length is strongly recommended. Methods include expressing SL as a percentage of
leg length (Cavanagh & Williams, 1982; Hof, 1996). If SF is used, SF can be rendered
dimensionless by dividing SF by √(g/L0) (Hof, 1996). Note that these two normalisation
methods will lead to the same conclusions since gravitational acceleration can be
assumed to be constant for this purpose.

The Hop (left) has a relatively high SF (Figure 8), with a low to medium DF.
This combination suggests that the runner generates relatively limited forward
propulsion during the stance phase. The resultant propulsion force is directed too
vertical. As a result, the push-off angle is not optimal, resulting for a given speed
in a non-maximal tflight. This phenomenon can have multiple causes, among which
insufficient leg extension, too upright trunk orientation, or insufficient leg swing
velocity.

The Push (right) involves large steps, and a DF that is medium to large. The large DF
occurs at the expense of a long tstance. The tflight is shorter than maximally possible, since
the propulsion force is oriented more horizontally or lower. The long tstance may be the
result of a movement strategy that includes prolonged tprop to prevent peak force
generation.

In the centre of the model a running style with intermediate DF and SF is described.
This running style is likely to be characterised by a relatively large knee-flexion at initial
contact (Figure 6.c, d) since leg configuration is associated geometrically with tstance and,
hence, tflight. Due to the expected ‘sitting posture’ this running style is coined ‘Sit’. Note
that three visually distinctive running styles (Bounce, Sit and Stick) are possible with
similar SF’s. The range of styles with corresponding SF may explain why some previous
studies might not have find significant differences in SF’s between runners despite
considerable variation in performance levels (Van Oeveren et al., 2019) or experience
(Agresta et al., 2018; Luedke et al., 2018; Van Oeveren et al., 2019).

The two axes of the Dual-axis framework should not be considered strictly orthogonal
as visualised since DF and SL are dependent. The stance phase is limited by geometrical
constraints (leg length, touch-down and take-off angles). Therefore, at high running
speeds, SL becomes more dependent on the flight phase. Consequently, with increasing
speed, the vertical axis will tilt to the right. Individual variation in dependencies across
speeds may reveal individual limitations and strengths. Note further that because of the

SPORTS BIOMECHANICS 25

10

### Stick

0

-10

10

### Hop

0

-10

10

### Push

0

-10

0

10

### Bounce

-10

1

Horizontal (m)

**Figure 8.** Illustration of the BCoM trajectories for the four most extreme styles with variations in step
frequency at a given speed (black vertical bar), flight phase (blue dashed line) and stance phase
(orange solid line). As a result of the expected BCoM trajectories each running style will display
different spatiotemporal parameters and runners can try to modify each style accordingly. Walk: long
tstance, short tflight resulting in a medium SF and a low VDstep. Bounce: short tstance, long tflight resulting
in a medium SF and a high VDstep. Hop: short tstance, short tflight resulting in a high SF and a medium
VDstep. Push: long tstance, long tflight resulting in a low SF and a large VDstep.

26 B. T. VAN OEVEREN ET AL.

interdependency between parameters, the same running styles can be obtained theore­
tically from other parameter settings as well.

Biomechanical predictors of performance and individual running economy can differ
(Folland et al., 2017; Kyrolainen et al., 2001; Nummela et al., 2007; Pizzuto et al., 2019;
Tawa & Louw, 2018; Williams & Cavanagh, 1985). Accordingly, the running style asso­
ciated with the highest absolute performance and the individually most economical
running style may diverge. To allow performance-oriented comparisons, proper normal­
isation for individual characteristics is required. The height or leg length normalisation
assumes proportionally scaled body anthropometrics, which could make runners with
different body sizes run in a dynamically similar fashion. In running, the leg length
normalisation is a logical first step since the pendulum length of the fast-moving limbs
will have more influence on the motion than the variation in body mass (Alexander, 1989).

To assess the biomechanical predictors for running economy, additional normal­
isation by mass may be appropriate. In the Dual-axis framework, this would imply that
the DF on the vertical axis is replaced by vertical stiffness, thereby taking into account
variation in body mass. The SL or SF may not require mass normalisation additional to
leg length normalisation since the natural frequency of a pendulum system depends on
its length, not on its mass (Alexander, 1989). Still, in a previous study, we found that a
7.5 kg increase in body mass was associated with a reduction of SF by one step per
minute (Van Oeveren et al., 2019). Differences in SF were also found due to age. It
seems that, in general, stronger and potentially heavier runners prefer larger steps. This
suggest that when running style is evaluated in relation with running economy, gender
differences and age should be considered to account for potential differences in mass
distribution or strength. Ultimately, it will be unfeasible to take all individual and
situational factors into account that collectively determine the most economical run­
ning style. Therefore, caution should be exerted in generalising across running popula­
tions and in using generic reference values in feedback applications. In general, it might
be more effective to design feedback systems that promote self-optimisation as sug­
gested in some of the SF-studies.

_**Future studies**_

The running styles defined by the Dual-axis framework may guide future research to
answer questions regarding performance improvement, injury prevalence. Also, ques­
tions regarding certain environmental contexts in relation to running biomechanics can
be answered more pointedly and consistently than has hitherto been possible. The
proposed framework has practical and heuristic value as it only requires that speed, SF
(normalised for leg length) and DF are measured and modelled in conjunction. We
acknowledge that even within each position in the framework small variations still exist
because of potential compensating moments generated by the trunk, arms and legs. The
landing/take-off asymmetry would additionally specify the BCoM trajectory. However,
current research on the landing/take-off asymmetry is limited. Therefore, strong conclu­
sions regarding the additional value of the landing/take-off asymmetry to the framework
remain to be determined. Nevertheless, we expect the Dual-axis framework to capture the
most fundamental differences in running styles, since it will cover most of the variations
in runners’ BCoM trajectories. We further expect that measuring whole-body kinematics

SPORTS BIOMECHANICS 27

will result in the same definition of running styles. The Dual-axis framework will help
explain variation between running styles and it provides a firmly motivated and rich basis
for defining and testing new hypotheses (which we have presented in this review as
expectations). Ideally, future research on running biomechanics will be done over a range
of speeds to identify potential individual speed-dependent differences. Gait modifications
to mimic the various running styles can be imposed by means of instructions requiring
combinations of long/short tstance with small/large SL. In addition, future research may
want to focus the effects of specific gait modifications emphasising limb movements such
as leg retraction, trunk lean, knee lift and arm swing to gain practical insights for runners
and their coaches.

**Conclusion**

Based on the current literature, we expect that the full spectrum of running styles can be
distinguished on the basis of SF, normalised by leg length, and DF for given speeds, as
stipulated in the proposed Dual-axis framework. Given that the goal of locomotion is to
transport the BCoM, the framework uses the sinusoidal BCoM trajectory in the sagittal
plane as the guiding principle. We expect that the framework will help to describe the most
fundamental differences in running styles since the BCoM movements depend mechani­
cally on the GRF patterns and limb and trunk kinematics. The categorisation of the five
styles, coined ‘Stick’, ‘Bounce’, ‘Push’, ‘Hop’, and ‘Sit’, can be used to study the effects of gait
modification and to help the interpretation of study results. By identifying the key char­
acteristics to differentiate running styles, this review and the synthesised Dual-axis frame­
work are intended to provide a unified concept for interpreting measurements, for
conducting future research on performance, running economy and injury risk, as well as
for designing and testing coaching interventions.

**Disclosure statement**

No potential conflict of interest was reported by the author(s).

**Funding**

This study was supported by COMMIT grant P3: “Sensor-based engagement for improved health”.
The funding agency had no involvement in the design or execution of the study.

**ORCID**

Ben T. van Oeveren <http://orcid.org/0000-0001-5090-7637>
Cornelis J. de Ruiter <http://orcid.org/0000-0003-0278-4235>
Peter J. Beek <http://orcid.org/0000-0002-0917-8548>
Jaap H. van Dieën <http://orcid.org/0000-0002-7719-5585>

28 B. T. VAN OEVEREN ET AL.

**References**

Adams, D., Pozzi, F., Willy, R. W., Carrol, A., & Zeni, J. (2018). Altering cadence or vertical

oscillation during running: Effects on running related injury factors. _International Journal of_
_Sports Physical Therapy_, _13_ [(4), 633–642. https://doi.org/10.26603/ijspt20180633](https://doi.org/10.26603/ijspt20180633)
Agresta, C. E., Peacock, J., Housner, J., Zernicke, R. F., & Zendler, J. D. (2018, December).

Experience does not influence injury-related joint kinematics and kinetics in distance runners.
_Gait and Posture_, _61_ [, 13–18. https://doi.org/10.1016/j.gaitpost.2017.12.020](https://doi.org/10.1016/j.gaitpost.2017.12.020)
Alexander, R. M. (1989). Optimization and gaits in the locomotion of vertebrates. _Physiological_

_Reviews_, _69_ [(4), 1199–1227. https://doi.org/10.1152/physrev.1989.69.4.1199](https://doi.org/10.1152/physrev.1989.69.4.1199)
Aminiaghdam, S., Rode, C., Müller, R., & Blickhan, R. (2017). Increasing trunk flexion transforms

human leg function into that of birds despite different leg morphology. _The Journal of_
_Experimental Biology_, _220_ [(3), 478–486. https://doi.org/10.1242/jeb.148312](https://doi.org/10.1242/jeb.148312)
Arampatzis, A., Brüggemann, G., & Metzler, V. (1999). The effect of speed on leg stiffness and joint

kinetics in human running. _Journal of Biomechanics_, _32_ (12), 1349–1353. [https://doi.org/10.](<https://doi.org/10.1016/s0021-9290(99)00133-5>)
[1016/s0021-9290(99)00133-5](<https://doi.org/10.1016/s0021-9290(99)00133-5>)
Arellano, C. J., & Kram, R. (2011). The effects of step width and arm swing on energetic cost and

lateral balance during running. _Journal of Biomechanics_, _44_ [(7), 1291–1295. https://doi.org/10.](https://doi.org/10.1016/j.jbiomech.2011.01.002)
[1016/j.jbiomech.2011.01.002](https://doi.org/10.1016/j.jbiomech.2011.01.002)
Arellano, C. J., & Kram, R. (2012). The energetic cost of maintaining lateral balance during human

running. _Medicine & Science in Sports & Exercise, 43_ [(Suppl 1), 427–434. doi:10.1152/](https://doi.org/10.1152/japplphysiol.00554.2011)
[japplphysiol.00554.2011.](https://doi.org/10.1152/japplphysiol.00554.2011)
Arellano, C. J., & Kram, R. (2014). Partitioning the metabolic cost of human running: A task-by
task approach. _Integrative and Comparative Biology_, _54_ [(6), 1084–1098. https://doi.org/10.1093/](https://doi.org/10.1093/icb/icu033)
[icb/icu033](https://doi.org/10.1093/icb/icu033)
Bailey, J., Mata, T., & Mercer, J. A. (2017). Is the relationship between stride length, frequency, and

velocity influenced by running on a treadmill or overground? _International Journal of Exercise_
_Science_, _10_ (7), 1067–1075.
Barnes, K. R., McGuigan, R., Kilding, E., Barnes, A., McGuigan, K. R., Kilding, M. R., Barnes, R.,

McGuigan, R., Kilding, A., & Ilding, A. N. E. K. (2014). Lower-body determinants of running
economy in male and female distance runners. _Journal of Strength and Conditioning Research_,
_28_ [(5), 1289–1297. https://doi.org/10.1519/JSC.0000000000000267](https://doi.org/10.1519/JSC.0000000000000267)
Bezodis, I. N., Kerwin, D. G., & Salo, A. I. T. (2008). Lower-limb mechanics during the support

phase of maximum-velocity sprint running. _Medicine and Science in Sports and Exercise_, _40_ (4),
[707–715. https://doi.org/10.1249/MSS.0b013e318162d162](https://doi.org/10.1249/MSS.0b013e318162d162)
Black, M. I., Handsaker, J. C., Allen, S. J., Forrester, S. E., & Folland, J. P. (2018). Is there an optimal

speed for economical running? _International Journal of Sports Physiology and Performance_, _13_
[(1), 75–81. https://doi.org/10.1123/ijspp.2017-0015](https://doi.org/10.1123/ijspp.2017-0015)
Blazevich, A. (2017). _Sports biomechanics_ (3th ed.). Bloomsbury.
Blickhan, R. (1989). The spring-mass model for running and hopping. _Journal of Biomechanics_, _22_

[(11), 1217–1227. https://doi.org/10.1016/0021-9290(89)90224-8](<https://doi.org/10.1016/0021-9290(89)90224-8>)
Blum, Y., Lipfert, S. W., & Seyfarth, A. (2009). Effective leg stiffness in running. _Journal of_

_Biomechanics_, _42_ [(14), 2400–2405. https://doi.org/10.1016/j.jbiomech.2009.06.040](https://doi.org/10.1016/j.jbiomech.2009.06.040)
Blum, Y., Lipfert, S. W., Rummel, J., & Seyfarth, A. (2010). Swing leg control in human running.

_Bioinspiration and Biomimetics_, _5_ [(2), 2. https://doi.org/10.1088/1748-3182/5/2/026006](https://doi.org/10.1088/1748-3182/5/2/026006)
Boyer, E. R., Rooney, B. D., & Derrick, T. R. (2014). Rearfoot and midfoot or forefoot impacts in

habitually shod runners. _Medicine and Science in Sports and Exercise_, _46_ [(7), 1384–1391. https://](https://doi.org/10.1249/MSS.0000000000000234)
[doi.org/10.1249/MSS.0000000000000234](https://doi.org/10.1249/MSS.0000000000000234)
Bredeweg, S. W., Kluitenberg, B., Bessem, B., & Buist, I. (2013). Differences in kinetic variables

between injured and noninjured novice runners: A prospective cohort study. _Journal of Science_
_and Medicine in Sport_, _16_ [(3), 205–210. https://doi.org/10.1016/j.jsams.2012.08.002](https://doi.org/10.1016/j.jsams.2012.08.002)
Breine, B., Malcolm, P., Frederick, E. C., & de Clercq, D. (2014). Relationship between running

speed and initial foot contact patterns. _Medicine and Science and Sports and Exercise_, _46_ (8),
[1595–1603. https://doi.org/10.1249/MSS.0000000000000267](https://doi.org/10.1249/MSS.0000000000000267)

SPORTS BIOMECHANICS 29

Breine, B., Malcolm, P., Van Caekenberghe, I., Fiers, P., Frederick, E. C., & De Clercq, D. (2017).

Initial foot contact and related kinematics affect impact loading rate in running. _Journal of_
_Sports Sciences_, _35_ [(15), 1556–1564. https://doi.org/10.1080/02640414.2016.1225970](https://doi.org/10.1080/02640414.2016.1225970)
Bridgett, L. A., & Linthorne, N. P. (2006). Changes in long jump take-off technique with increasing

run-up speed. _Journal of Sports Sciences_, _24_ (8), 889–897. [https://doi.org/10.1080/](https://doi.org/10.1080/02640410500298040)
[02640410500298040](https://doi.org/10.1080/02640410500298040)
Brindle, R. A., Taylor, J. B., Rajek, C., Weisbrod, A., & Ford, K. R. (2019). Association between

temporal spatial parameters and overuse injury history in runners: A systematic review and
meta-analysis. _Sports Medicine, 50_ [(2), 331–342. https://doi.org/10.1007/s40279-019-01207-5](https://doi.org/10.1007/s40279-019-01207-5)
Brughelli, M., & Cronin, J. (2008a). Influence of running velocity on vertical, leg and joint stiffness:

Modelling and recommendations for future research. _Sports Medicine_, _38_ [(8), 647–657. https://](https://doi.org/10.2165/00007256-200838080-00003)
[doi.org/10.2165/00007256-200838080-00003](https://doi.org/10.2165/00007256-200838080-00003)
Brughelli, M., & Cronin, J. (2008b). A review of research on the mechanical stiffness in running

and jumping: Methodology and implications. _Scandinavian Journal of Medicine & Science in_
_Sports_, _18_ [(4), 417–426. https://doi.org/10.1111/j.1600-0838.2008.00769.x](https://doi.org/10.1111/j.1600-0838.2008.00769.x)
Bruijn, S. M., Meijer, O. G., van Dieën, J. H., Kingma, I., & Lamoth, C. J. C. (2008). Coordination of

leg swing, thorax rotations, and pelvis rotations during gait: The organisation of total body
angular momentum. _Gait and Posture_, _27_ [(3), 455–462. https://doi.org/10.1016/j.gaitpost.2007.](https://doi.org/10.1016/j.gaitpost.2007.05.017)
[05.017](https://doi.org/10.1016/j.gaitpost.2007.05.017)
Bullimore, S. R., & Burn, J. F. (2006). Consequences of forward translation of the point of force

application for the mechanics of running. _Journal of Theoretical Biology_, _238_ (1), 211–219.
[https://doi.org/10.1016/j.jtbi.2005.05.011](https://doi.org/10.1016/j.jtbi.2005.05.011)
Bundle, M. W., & Weyand, P. G. (2012). Sprint exercise performance: Does metabolic power

matter? _Exercise and Sport Sciences Reviews_, _40_ (3), 174–182. [https://doi.org/10.1097/JES.](https://doi.org/10.1097/JES.0b013e318258e1c1)
[0b013e318258e1c1](https://doi.org/10.1097/JES.0b013e318258e1c1)
Bushnell, T., & Hunter, I. (2007). Differences in technique between sprinters and distance runners

at equal and maximal speeds. _Sports Biomechanics_, _6_ (3), 261–268. [https://doi.org/10.1080/](https://doi.org/10.1080/14763140701489728)
[14763140701489728](https://doi.org/10.1080/14763140701489728)
Carrard, A., Fontana, E., & Malatesta, D. (2018). Mechanical determinants of the u-shaped speed
energy cost of running relationship. _Frontiers in Physiology_, _9_ . [https://doi.org/10.3389/fphys.](https://doi.org/10.3389/fphys.2018.01790)
[2018.01790](https://doi.org/10.3389/fphys.2018.01790)
Cavagna, G. A., Heglund, N. C., & Taylor, C. R. (1977). Mechanical work in terrestrial locomotion:

Two basic mechanisms for minimizing energy expenditure. _American Journal of Physiology -_
_Regulatory Integrative and Comparative Physiology_, _2_ (3), R243–R261. [https://doi.org/10.1152/](https://doi.org/10.1152/ajpregu.1977.233.5.r243)
[ajpregu.1977.233.5.r243](https://doi.org/10.1152/ajpregu.1977.233.5.r243)
Cavagna, G. A., & Kaneko, M. (1977). Mechanical work and efficiency in level walking and running.

_The Journal of Physiology_, _268_ [(2), 467–481. https://doi.org/10.1113/jphysiol.1977.sp011866](https://doi.org/10.1113/jphysiol.1977.sp011866)
Cavanagh, P. R., & Williams, K. R. (1982). The effect of stride length variation on oxygen uptake

during distance running. _Medicine and Science in Sports and Exercise_, _14_ [(1), 30–35. https://doi.](https://doi.org/10.1249/00005768-198201000-00006)
[org/10.1249/00005768-198201000-00006](https://doi.org/10.1249/00005768-198201000-00006)
Cavagna, G. A., Willems, P. A., Franzetti, P., & Detrembleur, C. (1991). The two power limits

conditioning step frequency in human running. _The Journal of Physiology_, _437_ [, 95–108. https://](https://doi.org/10.1113/jphysiol.1991.sp018586)
[doi.org/10.1113/jphysiol.1991.sp018586](https://doi.org/10.1113/jphysiol.1991.sp018586)
Cavagna, G. A. (2006). The landing-take-off asymmetry in human running. _Journal of_

_Experimental Biology_, _209_ [(20), 4051–4060. https://doi.org/10.1242/jeb.02344](https://doi.org/10.1242/jeb.02344)
Cavagna, G. A., Legramandi, M. A., & Peyre-Tartaruga, L. A. (2008). The landing-take-off

asymmetry of human running is enhanced in old age. _Journal of Experimental Biology_, _211_
[(10), 1571–1578. https://doi.org/10.1242/jeb.013805](https://doi.org/10.1242/jeb.013805)
Cavagna, G. A. (2009). The two asymmetries of the bouncing step. _European Journal of Applied_

_Physiology_, _107_ [(6), 739–742. https://doi.org/10.1007/s00421-009-1179-2](https://doi.org/10.1007/s00421-009-1179-2)
Cavagna, G. A. (2010). Symmetry and asymmetry in bouncing gaits. _Symmetry_, _2_ (3), 1270–1321.

[https://doi.org/10.3390/sym2031270](https://doi.org/10.3390/sym2031270)

30 B. T. VAN OEVEREN ET AL.

Ceyssens, L., Vanelderen, R., Barton, C., Malliaras, P., & Dingenen, B. (2019). Biomechanical risk

factors associated with running-related injuries: A systematic review. _Sports Medicine_, _49_ (7),
[1095–1115. https://doi.org/10.1007/s40279-019-01110-z](https://doi.org/10.1007/s40279-019-01110-z)
Chang, Y., Huang, H. C., Hamerski, C. M., & Kram, R. (2000). The independent effects of gravity

and inertia on running mechanics. _Journal of Experimental Biology_, _203_ (2), 229–238.
Chang, Y., & Kram, R. (2017). Metabolic cost of generating horizontal forces during human

running. _Journal of Applied Physiology_, _86_ [(5), 1657–1662. https://doi.org/10.1152/jappl.1999.86.](https://doi.org/10.1152/jappl.1999.86.5.1657)
[5.1657](https://doi.org/10.1152/jappl.1999.86.5.1657)
Chapman, R. F., Laymon, A. S., Wilhite, D. P., McKenzie, J. M., Tanner, D., & Stager, J. M. (2012).

Ground contact time as an indicator of metabolic cost in elite distance runners. _Medicine and_
_Science in Sports and Exercise_, _44_ [(5), 917–925. https://doi.org/10.1249/MSS.0b013e3182400520](https://doi.org/10.1249/MSS.0b013e3182400520)
Chumanov, E. S., Schache, A. G., Heiderscheit, B. C., & Thelen, D. G. (2012). Hamstrings are most

susceptible to injury during the late swing phase of sprinting. _British Journal of Sports Medicine_,
_46_ [(2), 90. https://doi.org/10.1136/bjsports-2011-090176](https://doi.org/10.1136/bjsports-2011-090176)
Clark, K. P., Ryan, L. J., & Weyand, P. G. (2014). Foot speed, foot-strike and footwear: Linking gait

mechanics and running ground reaction forces. _Journal of Experimental Biology_, _217_ (12), 2037–
[2040. https://doi.org/10.1242/jeb.099523](https://doi.org/10.1242/jeb.099523)
Clark, K. P., & Weyand, P. G. (2014). Are running speeds maximized with simple-spring stance

mechanics? _Journal of Applied Physiology_, _117_ (6), 604–615. [https://doi.org/10.1152/japplphy](https://doi.org/10.1152/japplphysiol.00174.2014)
[siol.00174.2014](https://doi.org/10.1152/japplphysiol.00174.2014)
Clark, K. P., Ryan, L. J., & Weyand, P. G. (2017). A general relationship links gait mechanics and

running ground reaction forces. _The Journal of Experimental Biology_, _220_ [(2), 247–258. https://](https://doi.org/10.1242/jeb.138057)
[doi.org/10.1242/jeb.138057](https://doi.org/10.1242/jeb.138057)
Coleman, D. R., Cannavan, D., Horne, S., & Blazevich, A. J. (2012). Leg stiffness in human

running: Comparison of estimates derived from previously published models to direct kine­
matic-kinetic measures. _Journal of Biomechanics_, _45_ [(11), 1987–1991. https://doi.org/10.1016/j.](https://doi.org/10.1016/j.jbiomech.2012.05.010)
[jbiomech.2012.05.010](https://doi.org/10.1016/j.jbiomech.2012.05.010)
Concejero, S. J., Granados, C., Irazusta, J., Letona, B. I., Lili, Z. J., Tam, N., & Gil, S. M. (2013).

Differences in ground contact time explain the less efficient running economy in North African
runners. _Biology of Sport_, _30_ [(3), 181–187. https://doi.org/10.5604/20831862.1059170](https://doi.org/10.5604/20831862.1059170)
Cunha, L., Alves, F., & Veloso, A. (2002). The touch-down and take-off angles in different phases

of 100m sprint run. _ISBS 2002, Caceres, Spain_, 527–530.
Cunninghan, R., Hunter, I., Seeley, M., Feland, B., Cunningham, R., Hunter, I., Seeley, M., &

Feland, B. (2013). Variations in running technique between female sprinters, middle, and
distance runners. _International Journal of Exercise_, _6_ ( _1_ ), 43–51.
da Rosa, R. G., Oliveira, H. B., Gomeñuka, N. A., Masiero, M. P. B., da Silva, E. S., Zanardi, A. P. J.,

de Carvalho, A. R., Schons, P., & Peyré-Tartaruga, L. A. (2019). Landing-takeoff asymmetries
applied to running mechanics: A new perspective for performance. _Frontiers in Physiology_, _10_ .
[https://doi.org/10.3389/fphys.2019.00415](https://doi.org/10.3389/fphys.2019.00415)
Dallam, G. M., Wilber, R. L., Jadelis, K., Fletcher, G., & Romanov, N. (2005). Effect of a global

alteration of running technique on kinematics and economy. _Journal of Sports Sciences_, _23_ (7),
[757–764. https://doi.org/10.1080/02640410400022003](https://doi.org/10.1080/02640410400022003)
Daniels, J. (2013). _Daniels’ Running Formula_ (3rd ed.). T. Hanlon, C. Marty, T. Wolpert, & P.

MacDonald (eds.). Human Kinetics Publishers, Inc.
de Ruiter, C. J., Verdijk, P. W. L. L., Werker, W., Zuidema, M. J., & de Haan, A. (2013, February).

Stride frequency in relation to oxygen consumption in experienced and novice runners.
_European Journal of Sport Science_, _14_ [, 37–41. https://doi.org/10.1080/17461391.2013.783627](https://doi.org/10.1080/17461391.2013.783627)
de Ruiter, C. J., van Oeveren, B. T., Francke, A., Zijlstra, P., & van Dieen, J. H. (2016). Running

speed can be predicted from foot contact time during outdoor over ground running. _Plos One_,
_11_ [(9), e0163023. https://doi.org/10.1371/journal.pone.0163023](https://doi.org/10.1371/journal.pone.0163023)
de Ruiter, C. J., van Daal, S., & van Dieën, J. H. (2020). Individual optimal step frequency during

outdoor running. _European Journal of Sport Science_, _20_ (2), 182–190. [https://doi.org/10.1080/](https://doi.org/10.1080/17461391.2019.1626911)
[17461391.2019.1626911](https://doi.org/10.1080/17461391.2019.1626911)

SPORTS BIOMECHANICS 31

Derrick, T. R. (2004). The effects of knee contact angle on impact forces and accelerations.

_Medicine and Science in Sports and Exercise_, _36_ (5), 832–837. [https://doi.org/10.1249/01.MSS.](https://doi.org/10.1249/01.MSS.0000126779.65353.CB)
[0000126779.65353.CB](https://doi.org/10.1249/01.MSS.0000126779.65353.CB)
Di Michele, R., & Merni, F. (2014). The concurrent effects of strike pattern and ground-contact

time on running economy. _Journal of Science and Medicine in Sport_, _17_ [(4), 414–418. https://doi.](https://doi.org/10.1016/j.jsams.2013.05.012)
[org/10.1016/j.jsams.2013.05.012](https://doi.org/10.1016/j.jsams.2013.05.012)
Dorn, T. W., Schache, A. G., & Pandy, M. G. (2012). Muscular strategy shift in human running:

Dependence of running speed on hip and ankle muscle performance. _Journal of Experimental_
_Biology_, _215_ [(13), 2347. https://doi.org/10.1242/jeb.075051](https://doi.org/10.1242/jeb.075051)
Dos Santos, A. F., Nakagawa, T. H., Nakashima, G. Y., Maciel, C. D., & Serrao, F. (2016). The

effects of forefoot striking, increasing step rate, and forward trunk lean running on trunk and
lower limb kinematics and comfort. _International Journal of Sports Medicine_, _37_ (5), 369–373.
[https://doi.org/10.1055/s-0035-1564173](https://doi.org/10.1055/s-0035-1564173)
Eriksson, M., Halvorsen, K. A., & Gullstrand, L. (2011). Immediate effect of visual and auditory

feedback to control the running mechanics of well-trained athletes. _Journal of Sports Sciences_, _29_
[(3), 253–262. https://doi.org/10.1080/02640414.2010.523088](https://doi.org/10.1080/02640414.2010.523088)
Farley, C., & Gonzalez, O. (1996). Leg stiffness and stride frequency in human running. _Journal of_

_Biomechanics_, _29_ [(2), 181–186. https://doi.org/10.1016/0021-9290(95)00029-1](<https://doi.org/10.1016/0021-9290(95)00029-1>)
Folland, J. P., Allen, S. A. M. J., Black, M. I., Handsaker, J. C., & Forrester, S. E. (2017). Running

technique is an important component of running economy and performance. _Medicine &_
_Science in Sports & Exercise_, _49_ [(7), 1412–1423. https://doi.org/10.1249/MSS.0000000000001245](https://doi.org/10.1249/MSS.0000000000001245)
Forrester, S. E., & Townend, J. (2015). The effect of running velocity on footstrike angle – A curve
clustering approach. _Gait & Posture_, _41_ (1), 26–32. [https://doi.org/10.1016/j.gaitpost.2014.08.](https://doi.org/10.1016/j.gaitpost.2014.08.004)
[004](https://doi.org/10.1016/j.gaitpost.2014.08.004)
García-Pinillos, F., García-Ramos, A., Ramírez-Campillo, R., Latorre-Román, P. A., & Roche
Seruendo, L. E. (2019). How do spatiotemporal parameters and lower-body stiffness change
with increased running velocity? A comparison between novice and elite level runners. _Journal_
_of Human Kinetics_, _70_ [(1), 25–38. https://doi.org/10.2478/hukin-2019-0036](https://doi.org/10.2478/hukin-2019-0036)
García-Pinillos, F., Roche-Seruendo, L. E., Marcén-Cinca, N., Marco-Contreras, L. A., & Latorre
Román, P. A. (2018). Absolute reliability and concurrent validity of the stryd system for the
assessment of running stride kinematics at different velocities. _Journal of Strength and_
_Conditioning Research_, _35_ [(1), 1. https://doi.org/10.1519/jsc.0000000000002595](https://doi.org/10.1519/jsc.0000000000002595)
Garmin Ltd. or Subsidiaries. (2019). What is GPS? 2019 Annual Report and Form 10K. _Garmin ltd_ .
Giandolini, M., Arnal, P. J., Millet, G. Y., Peyrot, N., Samozino, P., Dubois, B., & Morin, J. B.

(2013). Impact reduction during running: Efficiency of simple acute interventions in recrea­
tional runners. _European Journal of Applied Physiology_, _113_ (3), 599–609. [https://doi.org/10.](https://doi.org/10.1007/s00421-012-2465-y)
[1007/s00421-012-2465-y](https://doi.org/10.1007/s00421-012-2465-y)
Gómez-Molina, J., Ogueta-Alday, A., Stickley, C., Cámara, J., Cabrejas-Ugartondo, J., & García
López, J. (2017). Differences in spatiotemporal parameters between trained runners and
untrained participants. _Journal of Strength and Conditioning Research_, _31_ (8), 2169–2175.
[https://doi.org/10.1519/JSC.0000000000001679](https://doi.org/10.1519/JSC.0000000000001679)
Goss, D. L., & Gross, M. T. (2012). A review of mechanics and injury trends among various

running styles. _U.S. Army Medical Department Journal_ [, 62–71. https://doi.org/10.1111/j.1365-](https://doi.org/10.1111/j.1365-2923.2009.03421.x)
[2923.2009.03421.x](https://doi.org/10.1111/j.1365-2923.2009.03421.x)
Grimmer, M., & Seyfarth, A. (2014). Mimicking human-like leg function in prosthetic limbs.

_Trends in Augmentation of Human Performance_, _2,_ 105–155. [https://doi.org/10.1007/978-](https://doi.org/10.1007/978-94-017-8932-5)
[94-017-8932-5](https://doi.org/10.1007/978-94-017-8932-5)
Gullstrand, L., Halvorsen, K., Tinmark, F., Eriksson, M., & Nilsson, J. (2009). Measurements of

vertical displacement in running, a methodological comparison. _Gait & Posture_, _30_ (1), 71–75.
[https://doi.org/10.1016/j.gaitpost.2009.03.001](https://doi.org/10.1016/j.gaitpost.2009.03.001)
Halvorsen, K., M. Eriksson, and L. Gullstrand. 2012. Acute effects of reducing vertical displace­

ment and step frequency on running economy. _Journal of Strength and Conditioning Research_,
_26_ [(8):2065–70. https://doi.org/10.1519/JSC.0b013e318239f87f.](https://doi.org/10.1519/JSC.0b013e318239f87f)

32 B. T. VAN OEVEREN ET AL.

Hamner, S. R., Seth, A., & Delp, S. L. (2010). Muscle contributions to propulsion and support

during running. _Journal of Biomechanics_, _43_ (14), 2709–2716. [https://doi.org/10.1016/j.jbio](https://doi.org/10.1016/j.jbiomech.2010.06.025)
[mech.2010.06.025](https://doi.org/10.1016/j.jbiomech.2010.06.025)
Hamner, S. R., & Delp, S. L. (2013). Muscle contributions to fore-aft and vertical body mass center

accelerations over a range of running speeds. _Journal of Biomechanics_, _46_ [(4), 780–787. https://](https://doi.org/10.1016/j.jbiomech.2012.11.024)
[doi.org/10.1016/j.jbiomech.2012.11.024](https://doi.org/10.1016/j.jbiomech.2012.11.024)
Hanley, B., & Mohan, A. K. (2014). Changes in gait during constant pace treadmill running.

_Journal of Strength and Conditioning Research_, _28_ [(5), 1219–1225. https://doi.org/10.1519/JSC.](https://doi.org/10.1519/JSC.0b013e3182a38796)
[0b013e3182a38796](https://doi.org/10.1519/JSC.0b013e3182a38796)
Haugen, T., McGhie, D., & Ettema, G. (2019). Sprint running: From fundamental mechanics to

practice—a review. _European Journal of Applied Physiology_, _119_ (6), 1273-1287. [https://doi.](https://doi.org/10.1007/s00421-019-04139-0)
[org/10.1007/s00421-019-04139-0](https://doi.org/10.1007/s00421-019-04139-0)
Heiderscheit, B. C., Chumanov, E. S., Michalski, M. P., Wille, C. M., & Ryan, M. B. (2011). Effects

of step rate manipulation on joint mechanics during running. _Medicine and Science in Sports_
_and Exercise_, _43_ [(2), 296–302. https://doi.org/10.1249/MSS.0b013e3181ebedf4](https://doi.org/10.1249/MSS.0b013e3181ebedf4)
Hinrichs, R. N. (1987). Upper extremity function in running. II: Angular momentum considera­

tions. _International Journal of Sport Biomechanics_, _3_ [(3), 242–263. https://doi.org/10.1123/ijsb.3.](https://doi.org/10.1123/ijsb.3.3.242)
[3.242](https://doi.org/10.1123/ijsb.3.3.242)
Hobara, H., Sato, T., Sakaguchi, M., & Nakazawa, K. (2012). Step frequency and lower extremity

loading during running. _International Journal of Sports Medicine_, _33_ (4), 310–313. [https://doi.](https://doi.org/10.1055/s-0031-1291232)
[org/10.1055/s-0031-1291232](https://doi.org/10.1055/s-0031-1291232)
Hof, A. L. (1996). Scaling data to body size. _Gait and Posture_, _4_ [(3), 222–223. https://doi.org/10.](<https://doi.org/10.1016/0966-6362(95)01057-2>)

[1016/0966-6362(95)01057-2](<https://doi.org/10.1016/0966-6362(95)01057-2>)
Hoogkamer, W., Kram, R., & Arellano, C. J. (2017). How biomechanical improvements in running

economy could break the 2-hour marathon barrier. _Sports Medicine_, _47_ [(9), 1739–1750. https://](https://doi.org/10.1007/s40279-017-0708-0)
[doi.org/10.1007/s40279-017-0708-0](https://doi.org/10.1007/s40279-017-0708-0)
Hoyt, D. F., Wickler, S. J., & Cogger, E. A. (2000). Time of contact and step length: The effect of

limb length, running speed, load carrying and incline. _The Journal of Experimental Biology_, _203_
(Pt 2), 221–227.
Hunter, J. P., Marshall, R. N., & McNair, P. J. (2004). Interaction of step length and step rate during

sprint running. _Medicine and Science in Sports and Exercise_, _36_ [(2), 261–271. https://doi.org/10.](https://doi.org/10.1249/01.MSS.0000113664.15777.53)
[1249/01.MSS.0000113664.15777.53](https://doi.org/10.1249/01.MSS.0000113664.15777.53)
Hunter, I., & Smith, G. A. (2007). Preferred and optimal stride frequency, stiffness and economy:

Changes with fatigue during a 1-h high-intensity run. _European Journal of Applied Physiology_,
_100_ [(6), 653–661. https://doi.org/10.1007/s00421-007-0456-1](https://doi.org/10.1007/s00421-007-0456-1)
Hunter, I., Lee, K., Ward, J., & Tracy, J. (2017). Self-optimization of stride length among

experienced and inexperienced runners. _International Journal of Exercise Science_, _10_ (3),
446–453.
Ishimura, K., & Sakurai, S. (2016). Asymmetry in determinants of running speed during curved

sprinting. _Journal of Applied Biomechanics_, _32_ (4), 394–400. [https://doi.org/10.1123/jab.2015-](https://doi.org/10.1123/jab.2015-0127)
[0127](https://doi.org/10.1123/jab.2015-0127)
Karssen, D. J. G., Haberland, M., Wisse, M., & Kim, S. (2011). The optimal swing-leg retraction

rate for running. _Proceedings - IEEE International Conference on Robotics and Automation_,
[Shanghai, 4000–4006. https://doi.org/10.1109/ICRA.2011.5980168](https://doi.org/10.1109/ICRA.2011.5980168)
Karssen, D. J. G., Haberland, M., Wisse, M., Kim, S., Karssen, J. G. D. D., Haberland, M., Wisse,

M., & Kim, S. (2015). The effects of swing-leg retraction on running performance: Analysis,
simulation, and experiment. _Robotica_, _33_ (10), 2137–2155. [https://doi.org/10.1017/](https://doi.org/10.1017/S0263574714001167)
[S0263574714001167](https://doi.org/10.1017/S0263574714001167)
Kenneally-Dabrowski, C. J. B., Brown, N. A. T., Lai, A. K. M., Perriman, D., Spratford, W., &

Serpell, B. G. (2019). Late swing or early stance? A narrative review of hamstring injury
mechanisms during high - speed running. _Scandinavian Journal of Medicine and Science in_
_Sports_, _29_ [(8), 1083–1091. https://doi.org/10.1111/sms.13437](https://doi.org/10.1111/sms.13437)

SPORTS BIOMECHANICS 33

Kluitenberg, B., Bredeweg, S. W., Zijlstra, S., Zijlstra, W., & Buist, I. (2012). Comparison of vertical

ground reaction forces during overground and treadmill running. A validation study. _BMC_
_Musculoskeletal Disorders_, _27_ [(13), 235. https://doi.org/10.1186/1471-2474-13-235](https://doi.org/10.1186/1471-2474-13-235)
Koblbauer, I. F., van Schooten, K. S., Verhagen, E. A., & van Dieën, J. H. (2013). Kinematic changes

during running-induced fatigue and relations with core endurance in novice runners. _Journal of_
_Science and Medicine in Sport_, _17_ [(4), 419–424. https://doi.org/10.1016/j.jsams.2013.05.013](https://doi.org/10.1016/j.jsams.2013.05.013)
Kugler, F., & Janshen, L. (2010). Body position determines propulsive forces in accelerated

running. _Journal of Biomechanics_, _43_ (2), 343–348. [https://doi.org/10.1016/j.jbiomech.2009.](https://doi.org/10.1016/j.jbiomech.2009.07.041)
[07.041](https://doi.org/10.1016/j.jbiomech.2009.07.041)
Kyröläinen, H., Belli, A., & Komi, P. V. (2001). Biomechanical factors affecting running economy.

_Medicine and Science in Sports and Exercise_, _33_ (8), 1330–1337. [https://doi.org/10.1097/](https://doi.org/10.1097/00005768-200108000-00014)
[00005768-200108000-00014](https://doi.org/10.1097/00005768-200108000-00014)
Lai, Y. J., Chou, W., Chu, I. H., Wang, Y. L., Lin, Y. J., Tu, S. J., & Guo, L. Y. (2020). Will the foot

strike pattern change at different running speeds with or without wearing shoes? _International_
_Journal of Environmental Research and Public Health_, _17_ (17), 1–9. [https://doi.org/10.3390/](https://doi.org/10.3390/ijerph17176044)
[ijerph17176044](https://doi.org/10.3390/ijerph17176044)
Le Meur, Y., Thierry, B., Rabita, G., Dorel, S., Honnorat, G., Brisswalter, J., & Hausswirth, C.

(2013). Spring-mass behaviour during the run of an international triathlon competition.
_International Journal of Sports Medicine_, _34_ (8), 748–755. [https://doi.org/10.1055/s-0032-](https://doi.org/10.1055/s-0032-1331205)
[1331205](https://doi.org/10.1055/s-0032-1331205)
Lee, C. R., & Farley, C. T. (1998). Determinants of the center of mass trajectory in human walking

and running. _Journal of Experimental Biology_, _201_ (21), 2935–2944.
Lenhart, R. L., Thelen, D. G., & Heiderscheit, B. C. (2014). Hip muscle loads during running at

various step rates. _Journal of Orthopaedic & Sports Physical Therapy_, _44_ (10), 766–774, A1-4.
[https://doi.org/10.2519/jospt.2014.5575](https://doi.org/10.2519/jospt.2014.5575)
Lieberman, D. E., Venkadesan, M., Werbel, W. A., Daoud, A. I., D’Andrea, S., Davis, I. S.,

Mang’eni, R. O., & Pitsiladis, Y. (2010). Foot strike patterns and collision forces in habitually
barefoot versus shod runners. _Nature_, _463_ [(7280), 531–535. https://doi.org/10.1038/nature08723](https://doi.org/10.1038/nature08723)
Lieberman, D. E., Warrener, A. G., Wang, J., & Castillo, E. R. (2015). Effects of stride frequency

and foot position at landing on braking force, hip torque, impact peak force and the metabolic
cost of running in humans. _Journal of Experimental Biology_, _218_ (21), 3406–3414. [https://doi.](https://doi.org/10.1242/jeb.125500)
[org/10.1242/jeb.125500](https://doi.org/10.1242/jeb.125500)
Lin, Y., Gfoehler, M., & Pandy, M. G. (2014). Quantitative evaluation of the major determinants of

human gait. _Journal of Biomechanics_, _47_ (6), 1324–1331. [https://doi.org/10.1016/j.jbiomech.](https://doi.org/10.1016/j.jbiomech.2014.02.002)
[2014.02.002](https://doi.org/10.1016/j.jbiomech.2014.02.002)
Lipfert, S. W. (2010, April). _Kinematic and Dynamic Similarities Between Walking and Running_ .

Kovač (1st edn.).
Luedke, L. E., Heiderscheit, B. C., Williams, D. S. B., & Rauh, M. J. (2016). Influence of step rate on

shin injury and anterior knee pain in high school runners. _Medicine and Science in Sports and_
_Exercise_, _1_ [(5), 1244–1250. https://doi.org/10.1249/MSS.0000000000000890](https://doi.org/10.1249/MSS.0000000000000890)
Luedke, L. E., Heiderscheit, B. C., Williams, D. S. B., & Rauh. M. J. (2018). Factors associated with

self-selected step rate in high school cross country runners. _Journal of Strength and Conditioning_
_Research_ [. https://doi.org/10.1519/jsc.0000000000002891](https://doi.org/10.1519/jsc.0000000000002891)
Maas, E., De Bie, J., Vanfleteren, R., Hoogkamer, W., & Vanwanseele, B. (2018). Novice runners

show greater changes in kinematics with fatigue compared with competitive runners. _Sports_
_Biomechanics_, _17_ [(3), 350–360. https://doi.org/10.1080/14763141.2017.1347193](https://doi.org/10.1080/14763141.2017.1347193)
Mann, R., Meijer, K., Malisoux, L., Brunner, R., Urhausen, A., Nuehrenboerger, C., & Theisen, D.

(2014). Fluctuations in strike index and spatiotemporal parameters in previously injured vs
uninjured runners. _British Journal of Sports Medicine_, _48_ [(7), 632.2–633. https://doi.org/10.1136/](https://doi.org/10.1136/bjsports-2014-093494.196)
[bjsports-2014-093494.196](https://doi.org/10.1136/bjsports-2014-093494.196)
Mann, R., Malisoux, L., Nührenbörger, C., Urhausen, A., Meijer, K., & Theisen, D. (2015).

Association of previous injury and speed with running style and stride-to-stride fluctuations.
_Scandinavian Journal of Medicine & Science in Sports_, _25_ [(6), e638–645. https://doi.org/10.1111/](https://doi.org/10.1111/sms.12397)
[sms.12397](https://doi.org/10.1111/sms.12397)

34 B. T. VAN OEVEREN ET AL.

Martin, P. E. (1985). Mechanical and physiological responses to lower extremity loading during

running. _Medicine and Science in Sports and Exercise_, _17_ [(4), 427–433. https://doi.org/10.1249/](https://doi.org/10.1249/00005768-198508000-00004)
[00005768-198508000-00004](https://doi.org/10.1249/00005768-198508000-00004)
Maykranz, D., & Seyfarth, A. (2014). Compliant ankle function results in landing-take off

asymmetry in legged locomotion. _Journal of Theoretical Biology_, _349_, 44–49. [https://doi.org/](https://doi.org/10.1016/j.jtbi.2014.01.029)
[10.1016/j.jtbi.2014.01.029](https://doi.org/10.1016/j.jtbi.2014.01.029)
Mercer, J., & Dolgan, J. (2008). The physiological importance of preferred stride frequency during

running at different speeds. _JEPonline_, _11_ (3), 26–32. [http://faculty.css.edu/tboone2/asep/mer](http://faculty.css.edu/tboone2/asep/mercerjeponlinejune2008.pdf)
[cerjeponlinejune2008.pdf](http://faculty.css.edu/tboone2/asep/mercerjeponlinejune2008.pdf)
Milner, C. E., Davis, I. S., & Hamill, J. (2006). Free moment as a predictor of tibial stress fracture in

distance runners. _Journal of Biomechanics_, _39_ (15), 2819–2825. [https://doi.org/10.1016/j.jbio](https://doi.org/10.1016/j.jbiomech.2005.09.022)
[mech.2005.09.022](https://doi.org/10.1016/j.jbiomech.2005.09.022)
Modica, J. R., & Kram, R. (2005). Metabolic energy and muscular activity required for leg swing in

running. _Journal of Applied Physiology_, _98_ [(6), 2126–2131. https://doi.org/10.1152/japplphysiol.](https://doi.org/10.1152/japplphysiol.00511.2004)
[00511.2004](https://doi.org/10.1152/japplphysiol.00511.2004)
Moore, I. S., Jones, A. M., & Dixon, S. J. (2012). Mechanisms for improved running economy in

beginner runners. _Medicine and Science in Sports and Exercise_, _44_ (9), 1756–1763. [https://doi.](https://doi.org/10.1249/MSS.0b013e318255a727)
[org/10.1249/MSS.0b013e318255a727](https://doi.org/10.1249/MSS.0b013e318255a727)
Moore, I. S. (2016). Is there an economical running technique? A review of modifiable biome­

chanical factors affecting running economy. _Sports Medicine_, _46_ [(6), 793–807. https://doi.org/](https://doi.org/10.1007/s40279-016-0474-4)
[10.1007/s40279-016-0474-4](https://doi.org/10.1007/s40279-016-0474-4)
Moore, I. S., Jones, A. M., & Dixon, S. J. (2016). Reduced oxygen cost of running is related to

alignment of the resultant GRF and leg axis vector: A pilot study. _Scandinavian Journal of_
_Medicine and Science in Sports_, _26_ [(7), 809–815. https://doi.org/10.1111/sms.12514](https://doi.org/10.1111/sms.12514)
Mooses, M., Haile, D. W., Ojiambo, R., Sang, M., Mooses, K., Lane, A. R., & Hackney, A. C. (2018).

Shorter ground contact time and better running economy. _Journal of Strength and Conditioning_
_Research_, _35_ [(2):481–486. https://doi.org/10.1519/jsc.0000000000002669](https://doi.org/10.1519/jsc.0000000000002669)
Morin, J. B., Dalleau, G., Kyröläinen, H., Jeannin, T., & Belli, A. (2005). A simple method for

measuring stiffness during running. _Journal of Applied Biomechanics_, _21_ (2), 167–180. [https://](https://doi.org/10.1123/jab.21.2.167)
[doi.org/10.1123/jab.21.2.167](https://doi.org/10.1123/jab.21.2.167)
Morin, J. B., Samozino, P., Zameziati, K., & Belli, A. (2007). Effects of altered stride frequency and

contact time on leg-spring behavior in human running. _Journal of Biomechanics_, _40_ (15), 3341–
[3348. https://doi.org/10.1016/j.jbiomech.2007.05.001](https://doi.org/10.1016/j.jbiomech.2007.05.001)
Morin, J. B., Gimenez, P., Edouard, P., Arnal, P., Jiménez-Reyes, P., Samozino, P., Brughelli, M., &

Mendiguchia, J. (2015). Sprint acceleration mechanics: The major role of hamstrings in hor­
izontal force production. _Frontiers in Physiology, 6_ [. https://doi.org/10.3389/fphys.2015.00404](https://doi.org/10.3389/fphys.2015.00404)
Mousavi, S. H., Hijmans, J. M., Rajabi, R., Diercks, R., Zwerver, J., & van der Worp, H. (2019).

Kinematic risk factors for lower limb tendinopathy in distance runners: A systematic review and
meta-analysis. _Gait and Posture_, _69_ [, 13–24. https://doi.org/10.1016/j.gaitpost.2019.01.011](https://doi.org/10.1016/j.gaitpost.2019.01.011)
Munro, C. F., Miller, D. I., & Fuglevand, A. J. (1987). Ground reaction forces in running: A

reexamination. _Journal of Biomechanics_, _20_ [(2), 147–155. https://doi.org/10.1016/0021-9290(87)](<https://doi.org/10.1016/0021-9290(87)90306-X>)
[90306-X](<https://doi.org/10.1016/0021-9290(87)90306-X>)
Myers, M. J., & Steudel, K. (1985). Effect of limb mass and its distribution on the energetic cost of

running. _The Journal of Experimental Biology_, _116_, 363–373.
Napier, C., MacLean, C. L., Maurer, J., Taunton, J. E., & Hunt, M. A. (2018). Kinetic risk factors of

running-related injuries in female recreational runners. _Scandinavian Journal of Medicine and_
_Science in Sports_, _28_ [(10), 2164–2172. https://doi.org/10.1111/sms.13228](https://doi.org/10.1111/sms.13228)
Nemtsev, O., Nemtseva, N., & Kucherenko, J. (2015). Comparison of technique characteristics of

sprint running at maximal and submaximal speeds. _ISBS-Conference_, Poitiers, France, July, 882–
[885. https://isbs2015.sciencesconf.org/57286/document](https://isbs2015.sciencesconf.org/57286/document)
Nordin, A. D., Dufek, J. S., & Mercer, J. A. (2017). Three-dimensional impact kinetics with foot
strike manipulations during running. _Journal of Sport and Health Science_, _6_ [(4), 489–497. https://](https://doi.org/10.1016/j.jshs.2015.11.003)
[doi.org/10.1016/j.jshs.2015.11.003](https://doi.org/10.1016/j.jshs.2015.11.003)

SPORTS BIOMECHANICS 35

Nummela, A., Keränen, T., & Mikkelsson, L. O. (2007). Factors related to top running speed and

economy. _International Journal of Sports Medicine_, _28_ (8), 655–661. [https://doi.org/10.1055/s-](https://doi.org/10.1055/s-2007-964896)
[2007-964896](https://doi.org/10.1055/s-2007-964896)
Ogueta-Alday, A., Rodríguez-Marroyo, J. A., & García-López, J. (2014). Rearfoot striking runners

are more economical than midfoot strikers. _Medicine and Science in Sports and Exercise_, _46_ (3),
[580–585. https://doi.org/10.1249/MSS.0000000000000139](https://doi.org/10.1249/MSS.0000000000000139)
Orendurff, M. S., Kobayashi, T., Tulchin-Francis, K., Tullock, A. M. H., Villarosa, C., Chan, C., &

Strike, S. (2018). A little bit faster: Lower extremity joint kinematics and kinetics as recreational
runners achieve faster speeds. _Journal of Biomechanics_, _71_ [, 167–175. https://doi.org/10.1016/j.](https://doi.org/10.1016/j.jbiomech.2018.02.010)
[jbiomech.2018.02.010](https://doi.org/10.1016/j.jbiomech.2018.02.010)
Padulo, J., Annino, G., Migliaccio, G. M., D’Ottavio, S., & Tihanyi, Z. (2012). Kinematics of

running at different slopes and speeds. _Journal of Strength and Conditioning Research_, _26_ (5),
[1331–1339. https://doi.org/10.1519/JSC.0b013e318231aafa](https://doi.org/10.1519/JSC.0b013e318231aafa)
Pantoja, P. D., Morin, J. B., Peyré-Tartaruga, L. A., & Brisswalter, J. (2016). Running energy cost

and spring-mass behavior in young versus older trained athletes. _Medicine and Science in Sports_
_and Exercise_, _48_ [(9), 1779–1786. https://doi.org/10.1249/MSS.0000000000000959](https://doi.org/10.1249/MSS.0000000000000959)
Pavei, G., Seminati, E., Storniolo, J. L. L., & Peyré-Tartaruga, L. A. (2017). Estimates of running

ground reaction force parameters from motion analysis. _Journal of Applied Biomechanics_, _33_ (1),
[69–75. https://doi.org/10.1123/jab.2015-0329](https://doi.org/10.1123/jab.2015-0329)
Pizzuto, F., de Oliveira, C. F., Soares, T. S. A., Rago, V., Silva, G., & Oliveira, J. (2019). Relationship

between running economy and kinematic parameters in long-distance runners. _Journal of_
_Strength and Conditioning Research_, _33_ [(7), 1921–1928. https://doi.org/10.1519/JSC.000000000](https://doi.org/10.1519/JSC.0000000000003040)
[0003040](https://doi.org/10.1519/JSC.0000000000003040)
Plagenhoef, S., Evans, F. G., & Abdelnour, T. (1983). Anatomical data for analysing human

motion. _Research Quarterly for Exercise and Sport_, _54_ (2), 169–178. [https://doi.org/10.1080/](https://doi.org/10.1080/02701367.1983.10605290)
[02701367.1983.10605290](https://doi.org/10.1080/02701367.1983.10605290)
Pohl, M. B., Mullineaux, D. R., Milner, C. E., Hamill, J., & Davis, I. S. (2008). Biomechanical

predictors of retrospective tibial stress fractures in runners. _Journal of Biomechanics_, _41_ (6),
[1160–1165. https://doi.org/10.1016/j.jbiomech.2008.02.001](https://doi.org/10.1016/j.jbiomech.2008.02.001)
Pontzer, H., Holloway, J. H., Raichlen, D. A., Lieberman, D. E., Hall, M., Louis, S., Pontzer, H.,

Holloway, J. H., Raichlen, D. A., & Lieberman, D. E. (2009). Control and function of arm swing
in human walking and running. _Journal of Experimental Biology_, _212_ [(6), 523–534. https://doi.](https://doi.org/10.1242/jeb.024927)
[org/10.1242/jeb.024927](https://doi.org/10.1242/jeb.024927)
Preece, S. J., Mason, D., & Bramah, C. (2016). The coordinated movement of the spine and pelvis

during running. _Human Movement Science_, _45_ [, 110–118. https://doi.org/10.1016/j.humov.2015.](https://doi.org/10.1016/j.humov.2015.11.014)
[11.014](https://doi.org/10.1016/j.humov.2015.11.014)
Preece, S. J., Bramah, C., & Mason, D. (2019). The biomechanical characteristics of high-perfor­

mance endurance running. _European Journal of Sport Science_, _19_ [(6), 784–792. https://doi.org/](https://doi.org/10.1080/17461391.2018.1554707)
[10.1080/17461391.2018.1554707](https://doi.org/10.1080/17461391.2018.1554707)
Rashty, A. M. N., Sharbafi, M. A., & Seyfarth, A. (2014). SLIP with swing leg augmentation as a

model for running. _IEEE International Conference on Intelligent Robots and Systems_, Chicago,
[IL, 2543–2549. https://doi.org/10.1109/IROS.2014.6942909](https://doi.org/10.1109/IROS.2014.6942909)
Reenalda, J., Maas, M. T. F., & Koning, J. J. D. (2016). The influence of added mass on optimal step

length in running. _International Journal of Sports Physiology and Performance_, _11_ (7), 920–926.
[https://doi.org/10.1123/ijspp.2015-0182](https://doi.org/10.1123/ijspp.2015-0182)
Roche-Seruendo, L. E., García-Pinillos, F., Haicaguerre, J., Bataller-Cervero, A. V., Soto-Hermoso,

V. M., & Latorre-Román, P. (2018). Lack of influence of muscular performance parameters on
spatiotemporal adaptations with increased running velocity. _Journal of Strength and_
_Conditioning Research_, _32_ [(2), 409–415. https://doi.org/10.1519/JSC.0000000000001845](https://doi.org/10.1519/JSC.0000000000001845)
Santos-Concejero, J. (2014). Influence of the biomechanical variables of the gait cycle in

running. _International Journal of Sport Science_, _36_ (10), 95–108. [https://doi.org/10.5232/ricy](https://doi.org/10.5232/ricyde2014.03601)
[de2014.03601](https://doi.org/10.5232/ricyde2014.03601)
Santos-Concejero, J., Tam, N., Coetzee, D. R., Oliván, J., Noakes, T. D., & Tucker, R. (2017). Are

gait characteristics and ground reaction forces related to energy cost of running in elite Kenyan

36 B. T. VAN OEVEREN ET AL.

runners? _Journal of Sports Sciences_, _35_ (6), 531–538. [https://doi.org/10.1080/02640414.2016.](https://doi.org/10.1080/02640414.2016.1175655)
[1175655](https://doi.org/10.1080/02640414.2016.1175655)
Saunders, P. U, Pyne, D. B., Telford, R. D., & Hawley, J. A. (2004). Factors affecting running

economy in trained distance runners. _Sports Medicine_, _34_ [(7), 465–485. https://doi.org/10.2165/](https://doi.org/10.2165/00007256-200434070-00005)
[00007256-200434070-00005](https://doi.org/10.2165/00007256-200434070-00005)
Schache, A. G., Dorn, T. W., Wrigley, T. V., Brown, N. A. T., & Pandy, M. G. (2013). Stretch

and activation of the human biarticular hamstrings across a range of running speeds.
_European Journal of Applied Physiology_, _113_ (11), 2813–2828. [https://doi.org/10.1007/](https://doi.org/10.1007/s00421-013-2713-9)
[s00421-013-2713-9](https://doi.org/10.1007/s00421-013-2713-9)
Schache, A. G., Dorn, T. W., Williams, G. P., Brown, N. A. T., & Pandy, M. G. (2014). Lower-limb

muscular strategies for increasing running speed. _Journal of Orthopaedic and Sports Physical_
_Therapy_, _44_ [(10), 813–824. https://doi.org/10.2519/jospt.2014.5433](https://doi.org/10.2519/jospt.2014.5433)
Schmitz, A., Pohl, M. B., Woods, K., & Noehren, B. (2014). Variables during swing associated with

decreased impact peak and loading rate in running. _Journal of Biomechanics_, _47_ (1), 32–38.
[https://doi.org/10.1016/j.jbiomech.2013.10.026](https://doi.org/10.1016/j.jbiomech.2013.10.026)
Seyfarth, A., Geyer, H., & Herr, H. (2003). Swing-leg retraction: A simple control model for stable

running. _Journal of Experimental Biology_, _206_ (15), 2547–2555. [https://doi.org/10.1242/jeb.](https://doi.org/10.1242/jeb.00463)
[00463](https://doi.org/10.1242/jeb.00463)
Sinning, W. E., & Forsyth, H. L. (1970). Lower-limb actions while running at different velocities.

_Medicine and Science in Sports_, _2_ (1), 28–34.
Slawinski, J. S., & Billat, V. L. (2004). Difference in Mechanical and Energy Cost between Highly,

Well, and Nontrained Runners. _Medicine & Science in Sports & Exercise_, _36_ (8), 1440–1446.
[https://doi.org/10.1249/01.MSS.0000135785.68760.96](https://doi.org/10.1249/01.MSS.0000135785.68760.96)
Snyder, K. L., & Farley, C. T. (2011). Energetically optimal stride frequency in running: The effects

of incline and decline. _The Journal of Experimental Biology_, _214_ [(Pt 12), 2089–2095. https://doi.](https://doi.org/10.1242/jeb.053157)
[org/10.1242/jeb.053157](https://doi.org/10.1242/jeb.053157)
Strohrmann, C., Seiter, J., Llorca, Y., & Tröster, G. (2013). Can smartphones help with running

technique? _Procedia Computer Science_, _19_ [, 902–907. https://doi.org/10.1016/j.procs.2013.06.123](https://doi.org/10.1016/j.procs.2013.06.123)
Sun, Y., Wei, S., Zhong, Y., Fu, W., Li, L., & Liu, Y. (2015). How joint torques affect hamstring

injury risk in sprinting swing-stance transition. _Medicine and Science in Sports and Exercise_, _47_
[(2), 373–380. https://doi.org/10.1249/MSS.0000000000000404](https://doi.org/10.1249/MSS.0000000000000404)
Tam, N., Tucker, R., Santos-Concejero, J., Prins, D., & Lamberts, R. P. (2018). Running economy:

Neuromuscular and joint stiffness contributions in trained runners. _International Journal of_
_Sports Physiology and Performance_, _14_ [(1), 16–22. https://doi.org/10.1123/ijspp.2018-0151](https://doi.org/10.1123/ijspp.2018-0151)
Tawa, N., & Louw, Q. (2018). Biomechanical factors associated with running economy and

performance of elite Kenyan distance runners: A systematic review. _Journal of Bodywork and_
_Movement Therapies_, _22_ [(1), 1–10. https://doi.org/10.1016/j.jbmt.2017.11.004](https://doi.org/10.1016/j.jbmt.2017.11.004)
Teng, H. L., & Powers, C. M. (2014). Sagittal plane trunk posture influences patellofemoral joint

stress during running. _Journal of Orthopaedic and Sports Physical Therapy_, _44_ (10), 785–792.
[https://doi.org/10.2519/jospt.2014.5249](https://doi.org/10.2519/jospt.2014.5249)
Thompson, M. A., Gutmann, A., Seegmiller, J., & McGowan, C. P. (2014). The effect of stride

length on the dynamics of barefoot and shod running. _Journal of Biomechanics_, _47_ (11), 2745–
[2750. https://doi.org/10.1016/j.jbiomech.2014.04.043](https://doi.org/10.1016/j.jbiomech.2014.04.043)
Tseh, W., Caputo, J. L., & Morgan, D. W. (2008). Influence of gait manipulation on running

economy in female distance runners. _Journal of Sports Science & Medicine_, _7_ (1), 91–95.
Usherwood, J. R. (2016). The muscle-mechanical compromise framework: Implications for the

scaling of gait and posture. _Journal of Human Kinetics_, _52_ [(1), 107–114. https://doi.org/10.1515/](https://doi.org/10.1515/hukin-2015-0198)
[hukin-2015-0198](https://doi.org/10.1515/hukin-2015-0198)
Van Caekenberghe, I., Segers, V., Aerts, P., Willems, P., & De Clercq, D. (2013). Joint kinematics

and kinetics of overground accelerated running versus running on an accelerated treadmill.
_Journal of the Royal Society Interface_, _10_ [(84), 84. https://doi.org/10.1098/rsif.2013.0222](https://doi.org/10.1098/rsif.2013.0222)
van Hooren, B., Goudsmit, J., Restrepo, J., & Vos, S. (2020). Real-time feedback by wearables in

running: Current approaches, challenges and suggestions for improvements. _Journal of Sports_
_Sciences_, _38_ [(2), 214–230. https://doi.org/10.1080/02640414.2019.1690960](https://doi.org/10.1080/02640414.2019.1690960)

SPORTS BIOMECHANICS 37

van Oeveren, B. T., de Ruiter, C. J., Beek, P. J., & van Dieën, J. H. (2017). Optimal stride frequencies

in running at different speeds. _PLoS ONE_, _12_ [(10). https://doi.org/10.1371/journal.pone.0184273](https://doi.org/10.1371/journal.pone.0184273)
Van Oeveren, B. T., De Ruiter, C. J., Hoozemans, M. J. M., Beek, P. J., & Van Dieën, J. H. (2019).

Inter-individual differences in stride frequencies during running obtained from wearable data.
_Journal of Sports Sciences_, _37_ [(17), 1996–2006. https://doi.org/10.1080/02640414.2019.1614137](https://doi.org/10.1080/02640414.2019.1614137)
Vernillo, G., Giandolini, M., Edwards, W. B., Morin, J. B., Samozino, P., Horvais, N., & Millet, G.

Y. (2017). Biomechanics and physiology of uphill and downhill running. _Sports Medicine_, _47_ (4),
[615–629. https://doi.org/10.1007/s40279-016-0605-y](https://doi.org/10.1007/s40279-016-0605-y)
Weyand, P., Sternlight, D., Bellizzi, M., & Wright, S. (2000). Faster top running speeds are achieved

with greater ground forces not more rapid leg movements. _Journal of Applied Physiology 89_ (5),
[1991–1999. https://doi.org/10.1152/jappl.2000.89.5.1991](https://doi.org/10.1152/jappl.2000.89.5.1991)
Weyand, P., Sandell, R., Prime, D., & Bundle, M. (2010). The biological limits to running speed are

imposed from the ground up. _Journal of Applied Physiology_, _108_ [(4), 950–961. https://doi.org/10.](https://doi.org/10.1152/japplphysiol.00947.2009)
[1152/japplphysiol.00947.2009](https://doi.org/10.1152/japplphysiol.00947.2009)
Whitcome, K. K., Miller, E. E., & Burns, J. L. (2017). Pelvic rotation effect on human stride

length: Releasing the constraint of obstetric selection. _Anatomical Record_, _300_ (4), 752–763.
[https://doi.org/10.1002/ar.23551](https://doi.org/10.1002/ar.23551)
Willems, P. A., Cavagna, G. A., & Heglund, N. C. (1995). External, internal and total work in

human locomotion. _The Journal of Experimental Biology_, _198_ (Pt 2), 379–393.
Williams, K. R., & Cavanagh, P. R. (1985). _Relationship between distance running running_

_economy, and performance_ . _Journal of Applied Physiology_, _63_ [(3), 1236–1245. http://jap.physiol](http://jap.physiology.org/content/63/3/1236.short)
[ogy.org/content/63/3/1236.short](http://jap.physiology.org/content/63/3/1236.short)
Williams, K. R., Cavanagh, P. R., & Ziff, J. L. (1987). Biomechanical studies of elite female distance

runners. _International Journal of Sports Medicine_, _8_ ( _Suppl S 2_ ), 107–118. [https://doi.org/10.](https://doi.org/10.1055/s-2008-1025715)
[1055/s-2008-1025715](https://doi.org/10.1055/s-2008-1025715)
Willson, J. D., Ratcliff, O. M., Meardon, S., & Willy, R. W. (2015). Influence of step length and

landing pattern on patellofemoral joint kinetics during running. _Scandinavian Journal of_
_Medicine & Science in Sports_, _25_ [(6), 736–743. https://doi.org/10.1111/sms.12383](https://doi.org/10.1111/sms.12383)
Willwacher, S., Goetze, I., & Fischer, K. M. (2016). The free moment in running and its relation to

joint loading and injury risk. _Footwear Science_, _8_ (1), 1-11. [https://doi.org/10.1080/19424280.](https://doi.org/10.1080/19424280.2015.1119890)
[2015.1119890](https://doi.org/10.1080/19424280.2015.1119890)

**Appendix**

m is the participant’s body mass in kilograms.

L0 leg length in metres at rest. This can be measured from trochanter major to the ground.
g is the acceleration due to gravity (−9.81 m/s \[2\] )

_**7.1 Transformations between speed, SF, SL**_

Vx ¼ \[SL\]

tstep

SF ¼ \[60\]

tstep

(1)

(2)

tstep¼tstanceþtflight (3)

tflight ¼ tstep� tstance (4)

tswing¼tflightþtstance (5)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

38 B. T. VAN OEVEREN ET AL.

_**7.2 Normalisation for body length**_

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

dstance¼vx � tstance (6)

dflight¼ SL� dstance (7)

dBCoM� ic¼ \[1\] (8)

2 \[�\] \[v\]\[x\]\[ �\] \[t\]\[stance\]

SF
SFnorm¼ ~~f f~~ **f** i ~~f~~ **f** i ~~f~~ **f** i **f** i ~~**f**~~ (9)
~~p~~ L0 _=_ g

tstance _;_ norm ¼ ~~p~~ \[t\]\[stance\] ~~f~~ L ~~f~~ **f** i 0 ~~f~~ **f** i _=_ ~~f~~ **f** i g **f** i ~~**f**~~ (10)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

_**7.3 Equations based on the ballistic trajectory**_

tlift¼ \[1\] (11)

2 \[�\] \[t\]\[flight\]

vyi¼ g � tlift (12)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

VDflight¼vyi � tlift þ \[1\]

2 \[g\]\[ �\] \[t\]\[lift\]

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

2 (13)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

vyi represents the initial vertical speed at the onset of the flight phase; the estimated time to reach
the peak of the flight phase. These equations assume that there is no difference between landing
and take-off height and air resistance can be neglected.

Steptangle ¼ g � tswing � \[2\] (14)

8

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

7.4 _**Spring properties**_
_Duty factor_

_Hooke’s law (linear spring)_

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

Vertical ratio ¼ \[VD\]\[ste\]\[p\] (15)

SL

DF ¼ tstance (16)
2 �ðtstanceþtflightÞ

� F ¼ y � k (17)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

Where in the case of running F = Fmax, y = VDstance. Note that F is in opposite direction of y.

The estimate of peak vertical force during contact (Morin et al., 2005)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

_\[π\]_ \[t\]\[fli\]\[g\]\[ht\]

2 \[ð\] t

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

Fmax¼ m � g � _\[π\]_

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

tstance

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

þ1Þ (18)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

Vertical displacement of the BCoM during the stance phase Morin et al., 2005)

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

\[max\]

m \[�\] \[t\]\[stance2\] _π_ \[2\]

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

(19)
8

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

VDstance ¼ � \[F\]\[max\]

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

þ g � \[t\]\[stance2\]
_π_ \[2\] 8

**f** i **f** i **f** i **f** i

**f** i **f** i **f** i **f** i

VDflight¼ VDstep� VDstance (20)

The estimate of vertical stiffness (Morin et al., 2005)

Fmax
Kvert¼ VDstance

The estimate of leg stiffness (Morin et al., 2005)

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i fi f **f** i f **f** **f** i f **f** i f **f** i f **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

SPORTS BIOMECHANICS 39

(21)

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

þ _VD_ stance (22)

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Δ _L_ ¼ _L_ 0 �

f **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

2

_L_ 0 \[2\] � _vx_ � _tstance_

s � 2 �

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

_L_ 0 \[2\] � _vx_ � _tstance_

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

2

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Kleg¼ \[F\]\[max\] (23)

ΔL

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

with ∆L representing the change in leg length, and vx the constant horizontal velocity.

_**7.5 Braking and propulsion**_
In constant speed running the netto impulse (∆I) equals zero.

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

ΔI ¼

ð

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

� � Fx _;_ brake � tbrake�

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

þ

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

ð

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

ðFx _;_ prop � tpropÞ ¼ 0 (24)
